@@ -1,7 +1,8 @@
 /*
  * BeerColorWidget.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -17,49 +18,44 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#ifndef BEERCOLORWIDGET_H
+#define BEERCOLORWIDGET_H
 
-#ifndef _BEERCOLORWIDGET_H
-#define   _BEERCOLORWIDGET_H
-
-class BeerColorWidget;
-
-#include <QWidget>
 #include <QColor>
-#include <QPaintEvent>
 #include <QImage>
 #include <QMetaProperty>
+#include <QPaintEvent>
 #include <QVariant>
-#include "recipe.h"
+#include <QWidget>
+
+#include "model/Recipe.h"
 
 /*!
  * \class BeerColorWidget
- * \author Philip G. Lee
  *
  * \brief Displays the approximate color of the beer on screen.
  */
-class BeerColorWidget : public QWidget
-{
+class BeerColorWidget : public QWidget {
    Q_OBJECT
 
 public:
-   BeerColorWidget(QWidget* parent=0);
+   BeerColorWidget(QWidget * parent = nullptr);
 
-   void setColor( QColor newColor );
+   void setColor(QColor newColor);
    //! Observe \b rec for changes in color, and automatically update.
-   void setRecipe( Recipe* rec );
-   
+   void setRecipe(Recipe* rec);
+
 public slots:
    void parseChanges(QMetaProperty prop, QVariant val);
-   
+
 protected:
    virtual void paintEvent(QPaintEvent *);
    QColor color;
 private:
    QImage glass;
    void showColor();
-   
+
    Recipe* recObs;
 };
 
-#endif   /* _BEERCOLORWIDGET_H */
-
+#endif
