@@ -1,7 +1,8 @@
 /*
  * BrewNoteWidget.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -18,16 +19,16 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#ifndef BREWNOTEWIDGET_H
+#define BREWNOTEWIDGET_H
+#pragma once
 
-#ifndef _BREWNOTEWIDGET_H
-#define _BREWNOTEWIDGET_H
-
-class BrewNoteWidget;
-
-#include <QWidget>
-#include <QDialog>
+#include <QDate>
+#include <QFocusEvent>
+#include <QString>
 #include <QMetaProperty>
 #include <QVariant>
+#include <QWidget>
 #include "ui_brewNoteWidget.h"
 
 // Forward declarations.
@@ -35,17 +36,15 @@ class BrewNote;
 
 /*!
  * \class BrewNoteWidget
- * \author Mik Firestone
  *
  * \brief View/controller widget that edits BrewNotes.
  */
-class BrewNoteWidget : public QWidget, public Ui::brewNoteWidget
-{
+class BrewNoteWidget : public QWidget, public Ui::brewNoteWidget {
     Q_OBJECT
 
 public:
-   BrewNoteWidget(QWidget *parent = 0);
-   virtual ~BrewNoteWidget() {}
+   BrewNoteWidget(QWidget *parent = nullptr);
+   virtual ~BrewNoteWidget();
 
    void setBrewNote(BrewNote* bNote);
    bool isBrewNote(BrewNote* note);
@@ -65,8 +64,8 @@ public slots:
 
    void updateFG();
    void updateFinalVolume_l();
-   void updateFermentDate(const QDateTime& datetime);
-   void updateDateFormat(Unit::unitDisplay display,Unit::unitScale scale);
+   void updateFermentDate(QDate const & datetime);
+   void updateDateFormat();
 
    void updateNotes();
 //   void saveAll();
@@ -74,13 +73,18 @@ public slots:
    void changed(QMetaProperty,QVariant);
    void showChanges(QString field = "");
 
-   void updateProjOg(Unit::unitDisplay oldUnit, Unit::unitScale oldScale);
-
+   /**
+    * The signal coming into this slot has two parameters:
+    *   • Measurement::SystemOfMeasurement oldSystemOfMeasurement,
+    *   • std::optional<Measurement::UnitSystem::RelativeScale> oldForcedScale
+    * However, because we have access to the underlying "standard units" value, we don't need to be told the old unit or
+    * scale.  Qt allows slots to ignore parameters - eg it is happy to deliver a two-parameter signal to a
+    * zero-parameter slot.  So that is what we do here.
+    */
+   void updateProjOg();
 
 private:
    BrewNote* bNoteObs;
-
-
 };
 
-#endif // _BREWNOTESWIDGET_H
+#endif
