@@ -17,18 +17,17 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 #include "BtTextEdit.h"
-#include "brewtarget.h"
-#include <QSettings>
+
 #include <QDebug>
- 
+#include <QSettings>
+
 BtTextEdit::BtTextEdit(QWidget *parent)
 {
    wasModified = false;
 
    // We will see if this works...
-   connect(this,SIGNAL(textChanged()),this,SLOT(textChanged()));
+   connect(this, &BtTextEdit::textChanged, this, &BtTextEdit::setTextChanged);
 
 }
 
@@ -39,7 +38,7 @@ BtTextEdit::BtTextEdit(const QString &text, QWidget *parent)
    wasModified = false;
 
    // We will see if this works...
-   connect(this,SIGNAL(textChanged()),this,SLOT(textChanged()));
+   connect(this, &BtTextEdit::textChanged, this, &BtTextEdit::setTextChanged);
 
 }
 
@@ -62,4 +61,4 @@ void BtTextEdit::focusOutEvent(QFocusEvent *e)
 }
 
 bool BtTextEdit::isModified()  { return wasModified; }
-void BtTextEdit::textChanged() { wasModified = true; }
+void BtTextEdit::setTextChanged() { wasModified = true; }
