@@ -1,6 +1,7 @@
 /*
  * EquipmentListModel.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  * - swstim <swstim@gmail.com>
@@ -18,33 +19,38 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 #include "EquipmentListModel.h"
-#include "equipment.h"
-#include "database.h"
-#include "recipe.h"
 
-EquipmentListModel::EquipmentListModel(QWidget* parent)
-   : QAbstractListModel(parent), recipe(0)
-{
-   connect( &(Database::instance()), SIGNAL(newEquipmentSignal(Equipment*)), this, SLOT(addEquipment(Equipment*)) );
-   connect( &(Database::instance()), SIGNAL(deletedEquipmentSignal(Equipment*)), this, SLOT(removeEquipment(Equipment*)) );
-   repopulateList();
+#include <QAbstractListModel>
+#include <QWidget>
+
+#include "database/ObjectStoreWrapper.h"
+#include "model/Equipment.h"
+#include "model/Recipe.h"
+
+EquipmentListModel::EquipmentListModel(QWidget* parent) :
+   QAbstractListModel(parent), recipe(0) {
+   connect(&ObjectStoreTyped<Equipment>::getInstance(), &ObjectStoreTyped<Equipment>::signalObjectInserted, this, &EquipmentListModel::addEquipment);
+   connect(&ObjectStoreTyped<Equipment>::getInstance(), &ObjectStoreTyped<Equipment>::signalObjectDeleted,  this, &EquipmentListModel::removeEquipment);
+   this->repopulateList();
+   return;
 }
 
-void EquipmentListModel::addEquipment(Equipment* equipment)
-{
+
+void EquipmentListModel::addEquipment(int equipmentId) {
+   Equipment* equipment = ObjectStoreWrapper::getByIdRaw<Equipment>(equipmentId);
+
    if( !equipment ||
       equipments.contains(equipment) ||
       equipment->deleted() ||
       !equipment->display()
    )
       return;
-   
+
    int size = equipments.size();
    beginInsertRows( QModelIndex(), size, size );
    equipments.append(equipment);
-   connect( equipment, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(equipChanged(QMetaProperty,QVariant)) );
+   connect( equipment, &NamedEntity::changed, this, &EquipmentListModel::equipChanged );
    endInsertRows();
 }
 
@@ -52,41 +58,43 @@ void EquipmentListModel::addEquipments(QList<Equipment*> equips)
 {
    QList<Equipment*>::iterator i;
    QList<Equipment*> tmp;
-   
+
    for( i = equips.begin(); i != equips.end(); i++ )
    {
       // if the equipment is not already in the list and
       // if the equipment has not been deleted and
       // if the equipment is to be displayed, then append it
       if( !equipments.contains(*i) &&
-          !(*i)->deleted()         &&  
+          !(*i)->deleted()         &&
            (*i)->display() )
          tmp.append(*i);
    }
-   
+
    int size = equipments.size();
    if (size+tmp.size())
    {
       beginInsertRows( QModelIndex(), size, size+tmp.size()-1 );
       equipments.append(tmp);
-   
+
       for( i = tmp.begin(); i != tmp.end(); i++ )
-         connect( *i, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(equipChanged(QMetaProperty,QVariant)) );
-   
+         connect( *i, &NamedEntity::changed, this, &EquipmentListModel::equipChanged );
+
       endInsertRows();
    }
 }
 
-void EquipmentListModel::removeEquipment(Equipment* equipment)
-{
-   int ndx = equipments.indexOf(equipment);
+
+void EquipmentListModel::removeEquipment(int equipmentId, std::shared_ptr<QObject> object) {
+   auto equipment = std::static_pointer_cast<Equipment>(object);
+   int ndx = equipments.indexOf(equipment.get());
    if( ndx > 0 )
    {
       beginRemoveRows( QModelIndex(), ndx, ndx );
-      disconnect( equipment, 0, this, 0 );
+      disconnect( equipment.get(), 0, this, 0 );
       equipments.removeAt(ndx);
       endRemoveRows();
    }
+   return;
 }
 
 void EquipmentListModel::removeAll()
@@ -103,38 +111,36 @@ void EquipmentListModel::removeAll()
 }
 
 void EquipmentListModel::equipChanged(QMetaProperty prop, QVariant val)
-{   
+{
    Equipment* eSend = qobject_cast<Equipment*>(sender());
-   
+
    // NOTE: how to get around the issue that the sender might live in
    // a different thread and therefore always cause eSend == 0?
    if( eSend == 0 )
       return;
-   
+
    QString propName(prop.name());
-   if( propName == "name" )
-   {
+   if (propName == PropertyNames::NamedEntity::name) {
       int ndx = equipments.indexOf(eSend);
-      if( ndx >= 0 )
+      if (ndx >= 0) {
          emit dataChanged( createIndex(ndx,0), createIndex(ndx,0) );
+      }
    }
 }
 
-void EquipmentListModel::recChanged(QMetaProperty prop, QVariant val)
-{
-   QString propName(prop.name());
-   if( propName == "equipment" )
-   {
-      Equipment* newEquip = qobject_cast<Equipment*>(BeerXMLElement::extractPtr(val));
-      // Now do something with the equipment.
+void EquipmentListModel::recChanged(QMetaProperty prop, QVariant val) {
+   if (prop.name()== PropertyNames::Recipe::equipment) {
+      Equipment* newEquip = val.value<Equipment *>();
+      // .:TODO:. Now do something with the equipment.
       Q_UNUSED(newEquip); // Until then, this will keep the compiler happy
    }
+   return;
 }
 
-void EquipmentListModel::repopulateList()
-{
+void EquipmentListModel::repopulateList() {
    removeAll();
-   addEquipments( Database::instance().equipments() );
+   addEquipments( ObjectStoreTyped<Equipment>::getInstance().getAllRaw() );
+   return;
 }
 
 Equipment* EquipmentListModel::at(int ndx)
@@ -164,9 +170,9 @@ void EquipmentListModel::observeRecipe(Recipe* rec)
    if( recipe )
       disconnect( recipe, 0, this, 0 );
    recipe = rec;
-   
+
    if( recipe )
-      connect( recipe, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(recChanged(QMetaProperty,QVariant)) );
+      connect( recipe, &NamedEntity::changed, this, &EquipmentListModel::recChanged );
 }
 
 int EquipmentListModel::rowCount( QModelIndex const& parent ) const
