@@ -1,6 +1,7 @@
 /*
  * FermentableDialog.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2015
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -17,21 +18,22 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include "FermentableDialog.h"
 
-#include <QWidget>
 #include <QDialog>
-#include <QString>
 #include <QInputDialog>
 #include <QList>
-#include "FermentableEditor.h"
-#include "FermentableDialog.h"
-#include "FermentableTableModel.h"
-#include "FermentableSortFilterProxyModel.h"
-#include "database.h"
-#include "recipe.h"
-#include "MainWindow.h"
-#include "fermentable.h"
+#include <QString>
+#include <QWidget>
 
+//#include "database/Database.h"
+#include "database/ObjectStoreWrapper.h"
+#include "FermentableEditor.h"
+#include "FermentableSortFilterProxyModel.h"
+#include "MainWindow.h"
+#include "model/Fermentable.h"
+#include "model/Recipe.h"
+#include "tableModels/FermentableTableModel.h"
 
 
 FermentableDialog::FermentableDialog(MainWindow* parent) :
@@ -53,11 +55,11 @@ FermentableDialog::FermentableDialog(MainWindow* parent) :
    fermTableProxy->setFilterKeyColumn(1);
 
    connect( pushButton_addToRecipe, SIGNAL( clicked() ), this, SLOT( addFermentable() ) );
-   connect( pushButton_edit, SIGNAL( clicked() ), this, SLOT( editSelected() ) );
-   connect( pushButton_remove, SIGNAL( clicked() ), this, SLOT( removeFermentable() ) );
+   connect( pushButton_edit, &QAbstractButton::clicked, this, &FermentableDialog::editSelected );
+   connect( pushButton_remove, &QAbstractButton::clicked, this, &FermentableDialog::removeFermentable );
    connect( pushButton_new, SIGNAL( clicked() ), this, SLOT( newFermentable() ) );
-   connect( tableWidget, SIGNAL( doubleClicked(const QModelIndex&) ), this, SLOT(addFermentable(const QModelIndex&)) );
-   connect( qLineEdit_searchBox, SIGNAL(textEdited(QString)), this, SLOT(filterFermentables(QString)));
+   connect( tableWidget, &QAbstractItemView::doubleClicked, this, &FermentableDialog::addFermentable );
+   connect( qLineEdit_searchBox, &QLineEdit::textEdited, this, &FermentableDialog::filterFermentables);
    // Let me see if this works
    fermTableModel->observeDatabase(true);
 }
@@ -119,75 +121,71 @@ void FermentableDialog::retranslateUi()
 #endif // QT_NO_TOOLTIP
 }
 
-void FermentableDialog::removeFermentable()
-{
+void FermentableDialog::removeFermentable() {
    QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
-   QModelIndex translated;
-   int row, size, i;
 
-   size = selected.size();
-   if( size == 0 )
+   int size = selected.size();
+   if (size == 0) {
       return;
-
-   // Make sure only one row is selected.
-   row = selected[0].row();
-   for( i = 1; i < size; ++i )
-   {
-      if( selected[i].row() != row )
-         return;
    }
 
-   translated = fermTableProxy->mapToSource(selected[0]);
-   Fermentable* ferm = fermTableModel->getFermentable(translated.row());
-   Database::instance().remove(ferm);
+   // Make sure only one row is selected.
+   int row = selected[0].row();
+   for (int i = 1; i < size; ++i) {
+      if (selected[i].row() != row) {
+         return;
+      }
+   }
+
+   QModelIndex translated = fermTableProxy->mapToSource(selected[0]);
+   auto ferm = fermTableModel->getRow(translated.row());
+   ObjectStoreWrapper::softDelete(*ferm);
+   return;
 }
 
-void FermentableDialog::editSelected()
-{
+void FermentableDialog::editSelected() {
    QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
-   QModelIndex translated;
-   int row, size, i;
 
-   size = selected.size();
-   if( size == 0 )
+   int size = selected.size();
+   if (size == 0) {
       return;
-
-   // Make sure only one row is selected.
-   row = selected[0].row();
-   for( i = 1; i < size; ++i )
-   {
-      if( selected[i].row() != row )
-         return;
    }
 
-   translated = fermTableProxy->mapToSource(selected[0]);
-   Fermentable* ferm = fermTableModel->getFermentable(translated.row());
-   fermEdit->setFermentable(ferm);
+   // Make sure only one row is selected.
+   int row = selected[0].row();
+   for (int i = 1; i < size; ++i) {
+      if (selected[i].row() != row) {
+         return;
+      }
+   }
+
+   QModelIndex translated = fermTableProxy->mapToSource(selected[0]);
+   auto ferm = fermTableModel->getRow(translated.row());
+   fermEdit->setFermentable(ferm.get());
    fermEdit->show();
+   return;
 }
 
-void FermentableDialog::addFermentable(const QModelIndex& index)
-{
+void FermentableDialog::addFermentable(const QModelIndex& index) {
    QModelIndex translated;
-   
-   // If there is no provided index, get the selected index.
-   if( !index.isValid() )
-   {
-      QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
-      int row, size, i;
 
-      size = selected.size();
-      if( size == 0 )
+   // If there is no provided index, get the selected index.
+   if (!index.isValid()) {
+      QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
+
+      int size = selected.size();
+      if (size == 0) {
          return;
+      }
 
       // Make sure only one row is selected.
-      row = selected[0].row();
-      for( i = 1; i < size; ++i )
-      {
-         if( selected[i].row() != row )
+      int row = selected[0].row();
+      for (int i = 1; i < size; ++i) {
+         if (selected[i].row() != row) {
             return;
+         }
       }
-      
+
       translated = fermTableProxy->mapToSource(selected[0]);
    }
    else
@@ -200,25 +198,31 @@ void FermentableDialog::addFermentable(const QModelIndex& index)
       else
          return;
    }
-   
-   Fermentable *ferm = fermTableModel->getFermentable(translated.row());
-   
-   Database::instance().addToRecipe( mainWindow->currentRecipe(), ferm );
+
+   MainWindow::instance().addFermentableToRecipe(fermTableModel->getRow(translated.row()));
+
+   return;
 }
 
-void FermentableDialog::newFermentable()
+void FermentableDialog::newFermentable(QString folder)
 {
    QString name = QInputDialog::getText(this, tr("Fermentable name"),
                                           tr("Fermentable name:"));
    if( name.isEmpty() )
       return;
-   
-   Fermentable* ferm = Database::instance().newFermentable();
-   ferm->setName(name);
+
+   Fermentable* ferm = new Fermentable(name);
+   if ( ! folder.isEmpty() )
+      ferm->setFolder(folder);
+
    fermEdit->setFermentable(ferm);
    fermEdit->show();
 }
 
+void FermentableDialog::newFermentable() {
+   newFermentable(QString());
+}
+
 void FermentableDialog::filterFermentables(QString searchExpression)
 {
     fermTableProxy->setFilterCaseSensitivity(Qt::CaseInsensitive);
