@@ -1,7 +1,8 @@
 /*
  * FermentableEditor.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -18,11 +19,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _FERMENTABLEEDITOR_H
-#define   _FERMENTABLEEDITOR_H
-
-class FermentableEditor;
+#ifndef FERMENTABLEEDITOR_H
+#define FERMENTABLEEDITOR_H
+#pragma once
 
 #include <QDialog>
 #include <QMetaProperty>
@@ -34,7 +33,6 @@ class Fermentable;
 
 /*!
  * \class FermentableEditor
- * \author Philip G. Lee
  *
  * \brief Fermentable view/controller dialog that allows you to edit Fermentables.
  */
@@ -43,14 +41,15 @@ class FermentableEditor : public QDialog, private Ui::fermentableEditor
    Q_OBJECT
 
 public:
-   FermentableEditor( QWidget *parent=0 );
+   FermentableEditor( QWidget *parent=nullptr );
    virtual ~FermentableEditor() {}
    void setFermentable( Fermentable* f );
+   void newFermentable( QString folder );
 
 public slots:
    void save();
    void clearAndClose();
-   void changed(QMetaProperty,QVariant);
+   void newFermentable();
 
 private:
    Fermentable* obsFerm;
@@ -58,7 +57,7 @@ private:
     *  the fermentable we are watching. If \b metaProp is null,
     *  then update all the UI elements at once.
     */
-   void showChanges(QMetaProperty* metaProp = 0);
+   void showChanges(QMetaProperty* metaProp = nullptr);
 };
 
-#endif   /* _FERMENTABLEEDITOR_H */
+#endif
