@@ -1,29 +1,28 @@
 /*
- * HeatCalculations.h is part of Brewtarget, and is Copyright Philip G. Lee
- * (rocketman768@gmail.com), 2009-2013.
+ * HeatCalculations.h is part of Brewtarget, and is Copyright the following
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
+ * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
-
+ *
  * Brewtarget is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _HEATCALCULATIONS_H
-#define   _HEATCALCULATIONS_H
+#ifndef HEATCALCULATIONS_H
+#define HEATCALCULATIONS_H
 
 class HeatCalculations;
 
 /*!
- * \class
- * \author Philip G. Lee
  *
  * \brief Algorithms and constants related to the thermodynamics of beer.
  */
@@ -38,9 +37,9 @@ public:
 
    /***Specific heats***/
    // Water's specific heat.
-   static double Cw_JKgK;
-   static double Cw_calGC;
-   static double Cgrain_calGC;
+   static double const Cw_JKgK;
+   static double const Cw_calGC;
+   static double const Cgrain_calGC;
 };
 
 #endif   /* _HEATCALCULATIONS_H */
