@@ -1,7 +1,8 @@
 /*
  * HopDialog.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2015
+ * authors 2009-2021
  * - Luke Vincent <luke.r.vincent@gmail.com>
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -18,21 +19,22 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include "HopDialog.h"
 
-#include <QWidget>
 #include <QDialog>
 #include <QInputDialog>
-#include <QString>
 #include <QList>
-#include "HopDialog.h"
-#include "database.h"
-#include "recipe.h"
-#include "MainWindow.h"
-#include "hop.h"
+#include <QString>
+#include <QWidget>
+
+//#include "database/Database.h"
+#include "database/ObjectStoreWrapper.h"
 #include "HopEditor.h"
-#include "HopTableModel.h"
-#include "HopTableModel.h"
 #include "HopSortFilterProxyModel.h"
+#include "MainWindow.h"
+#include "model/Hop.h"
+#include "model/Recipe.h"
+#include "tableModels/HopTableModel.h"
 
 HopDialog::HopDialog(MainWindow* parent) :
    QDialog(parent),
@@ -53,11 +55,11 @@ HopDialog::HopDialog(MainWindow* parent) :
    hopTableProxy->setFilterKeyColumn(1);
 
    connect( pushButton_addToRecipe, SIGNAL( clicked() ), this, SLOT( addHop() ) );
-   connect( pushButton_edit, SIGNAL( clicked() ), this, SLOT( editSelected() ) );
+   connect( pushButton_edit, &QAbstractButton::clicked, this, &HopDialog::editSelected );
    connect( pushButton_new, SIGNAL( clicked() ), this, SLOT( newHop() ) );
-   connect( pushButton_remove, SIGNAL( clicked() ), this, SLOT( removeHop() ));
-   connect( tableWidget, SIGNAL( doubleClicked(const QModelIndex&) ), this, SLOT( addHop(const QModelIndex&) ) );
-   connect( qLineEdit_searchBox, SIGNAL(textEdited(QString)), this, SLOT(filterHops(QString)));
+   connect( pushButton_remove, &QAbstractButton::clicked, this, &HopDialog::removeHop);
+   connect( tableWidget, &QAbstractItemView::doubleClicked, this, &HopDialog::addHop );
+   connect( qLineEdit_searchBox, &QLineEdit::textEdited, this, &HopDialog::filterHops);
 
    hopTableModel->observeDatabase(true);
 }
@@ -119,8 +121,7 @@ void HopDialog::retranslateUi()
 #endif // QT_NO_TOOLTIP
 }
 
-void HopDialog::removeHop()
-{
+void HopDialog::removeHop() {
    QModelIndex modelIndex, viewIndex;
    QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
    int row, size, i;
@@ -137,9 +138,11 @@ void HopDialog::removeHop()
          return;
    }
    modelIndex = hopTableProxy->mapToSource(selected[0]);
-   Hop *hop = hopTableModel->getHop(modelIndex.row());
-   if (hop)
-      Database::instance().remove(hop);
+   auto hop = hopTableModel->getRow(modelIndex.row());
+   if (hop) {
+      ObjectStoreWrapper::softDelete(*hop);
+   }
+   return;
 }
 
 void HopDialog::addHop(const QModelIndex& index)
@@ -174,10 +177,10 @@ void HopDialog::addHop(const QModelIndex& index)
       else
          return;
    }
-   
-   Hop *hop = hopTableModel->getHop(translated.row());
-   
-   Database::instance().addToRecipe( mainWindow->currentRecipe(), hop );
+
+   MainWindow::instance().addHopToRecipe(hopTableModel->getRow(translated.row()));
+
+   return;
 }
 
 void HopDialog::editSelected()
@@ -199,20 +202,29 @@ void HopDialog::editSelected()
    }
 
    translated = hopTableProxy->mapToSource(selected.value(0));
-   Hop *hop = hopTableModel->getHop(translated.row());
-   hopEditor->setHop(hop);
+   auto hop = hopTableModel->getRow(translated.row());
+   hopEditor->setHop(hop.get());
    hopEditor->show();
+   return;
 }
 
 void HopDialog::newHop()
+{
+   newHop(QString());
+}
+
+void HopDialog::newHop(QString folder)
 {
    QString name = QInputDialog::getText(this, tr("Hop name"),
                                           tr("Hop name:"));
    if( name.isEmpty() )
       return;
 
-   Hop* hop = Database::instance().newHop();
-   hop->setName(name);
+   // .:TODO:. Change to shared_ptr as potential memory leak
+   Hop* hop = new Hop(name);
+   if ( ! folder.isEmpty() )
+      hop->setFolder(folder);
+
    hopEditor->setHop(hop);
    hopEditor->show();
 }
