@@ -1,7 +1,8 @@
 /*
  * HopDialog.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2015
+ * authors 2009-2021
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -17,9 +18,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _HOPDIALOG_H
-#define _HOPDIALOG_H
+#ifndef HOPDIALOG_H
+#define HOPDIALOG_H
+#pragma once
 
 #include <QWidget>
 #include <QDialog>
@@ -38,7 +39,6 @@ class HopSortFilterProxyModel;
 
 /*!
  * \class HopDialog
- * \author Philip G. Lee
  *
  * \brief View/controller class for showing/editing the list of hops in the database.
  */
@@ -63,6 +63,8 @@ public:
    QLineEdit *qLineEdit_searchBox;
    //! @}
 
+   void newHop(QString folder);
+
 public slots:
    //! Add selected hop to current recipe.
    void addHop(const QModelIndex& = QModelIndex());
