@@ -1,7 +1,8 @@
 /*
  * HopEditor.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -18,11 +19,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _HOPEDITOR_H
-#define   _HOPEDITOR_H
-
-class HopEditor;
+#ifndef HOPEDITOR_H
+#define HOPEDITOR_H
+#pragma once
 
 #include "ui_hopEditor.h"
 #include <QMetaProperty>
@@ -33,7 +32,6 @@ class Hop;
 
 /*!
  * \class HopEditor
- * \author Philip G. Lee
  *
  * \brief View/controller class for modifying hops.
  */
@@ -42,10 +40,12 @@ class HopEditor : public QDialog, private Ui::hopEditor
    Q_OBJECT
 
 public:
-   HopEditor( QWidget *parent=0 );
+   HopEditor( QWidget *parent=nullptr );
    virtual ~HopEditor() {}
    //! Edit the given hop.
    void setHop( Hop* h );
+   //! Create a new hop
+   void newHop(QString folder);
 
 public slots:
    //! Save the changes.
@@ -53,6 +53,7 @@ public slots:
    //! Clear the dialog and close it.
    void clearAndClose();
    void changed(QMetaProperty,QVariant);
+   void newHop();
 
 private:
    Hop* obsHop;
@@ -60,7 +61,7 @@ private:
    /*! Updates the UI elements based on \b prop.
     *  If null, updates all UI elements.
     */
-   void showChanges(QMetaProperty* prop = 0);
+   void showChanges(QMetaProperty* prop = nullptr);
 };
 
-#endif   /* _HOPEDITOR_H */
+#endif
