@@ -1,8 +1,9 @@
- /*
+/*
  * MainWindow.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2022
  * - Dan Cavanagh <dan@dancavanagh.com>
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Maxime Lavigne <duguigne@gmail.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
@@ -22,86 +23,113 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#ifndef MAINWINDOW_H
+#define MAINWINDOW_H
+#pragma once
 
-#ifndef _MAINWINDOW_H
-#define _MAINWINDOW_H
+#include <functional>
+#include <memory> // For PImpl
 
-class MainWindow;
-
-#include <QWidget>
-#include <QMainWindow>
-#include <QString>
-#include <QVariant>
-#include <QFileDialog>
-#include <QPalette>
 #include <QCloseEvent>
-#include <QPrinter>
+#include <QFileDialog>
+#include <QMainWindow>
+#include <QPalette>
 #include <QPrintDialog>
+#include <QPrinter>
+#include <QString>
 #include <QTimer>
+#include <QUndoStack>
+#include <QVariant>
+#include <QWidget>
+
 #include "ui_mainWindow.h"
+#include "SimpleUndoableUpdate.h"
+
 
 // Forward Declarations
-class FermentableDialog;
-class HopDialog;
-class MiscDialog;
-class YeastDialog;
+
 class AboutDialog;
-class Recipe;
+class AlcoholTool;
+class AncestorDialog;
 class BeerColorWidget;
-class FermentableEditor;
-class MiscEditor;
-class HopEditor;
-class YeastEditor;
-class EquipmentEditor;
-class StyleEditor;
-class OptionDialog;
-class MashEditor;
-class MashStepEditor;
-class MashWizard;
 class BrewDayScrollWidget;
-class HtmlViewer;
-class ScaleRecipeTool;
-class RecipeFormatter;
-class OgAdjuster;
-class ConverterTool;
-class TimerListDialog;
-class PrimingDialog;
-class StrikeWaterDialog;
-class RecipeExtrasWidget;
-class RefractoDialog;
-class MashDesigner;
-class MashListModel;
-class PitchDialog;
 class BrewNoteWidget;
-class FermentableTableModel;
-class FermentableSortFilterProxyModel;
-class HopTableModel;
-class HopSortFilterProxyModel;
-class MiscTableModel;
-class MiscSortFilterProxyModel;
-class YeastTableModel;
-class YeastSortFilterProxyModel;
-class MashStepTableModel;
+class BtDatePopup;
+class ConverterTool;
+class EquipmentEditor;
 class EquipmentListModel;
+class FermentableDialog;
+class FermentableEditor;
+class FermentableSortFilterProxyModel;
+class FermentableTableModel;
+class HopDialog;
+class HopEditor;
+class HopSortFilterProxyModel;
+class HopTableModel;
+class HtmlViewer;
+class HydrometerTool;
+class MashDesigner;
+class MashEditor;
+class MashListModel;
+class MashStepEditor;
+class MashStepTableModel;
+class MashWizard;
+class MiscDialog;
+class MiscEditor;
+class MiscSortFilterProxyModel;
+class MiscTableModel;
+class NamedMashEditor;
+class OgAdjuster;
+class OptionDialog;
+class PitchDialog;
+class PrimingDialog;
+class PrintAndPreviewDialog;
+class Recipe;
+class RecipeExtrasWidget;
+class RecipeFormatter;
+class RefractoDialog;
+class ScaleRecipeTool;
+class StrikeWaterDialog;
+class StyleEditor;
 class StyleListModel;
 class StyleSortFilterProxyModel;
-class NamedMashEditor;
-class BtDatePopup;
+class TimerMainDialog;
+class WaterDialog;
+class WaterEditor;
+class WaterListModel;
+class YeastDialog;
+class YeastEditor;
+class YeastSortFilterProxyModel;
+class YeastTableModel;
 
 /*!
  * \class MainWindow
- * \author Philip G. Lee
  *
  * \brief Brewtarget's main window. This is a view/controller class.
  */
-class MainWindow : public QMainWindow, public Ui::mainWindow
-{
+class MainWindow : public QMainWindow, public Ui::mainWindow {
    Q_OBJECT
 
    friend class OptionDialog;
 public:
-   MainWindow(QWidget* parent=0);
-   virtual ~MainWindow() {}
+   MainWindow(QWidget* parent=nullptr);
+   virtual ~MainWindow();
+
+   static MainWindow & instance();
+   /**
+    * \brief Call at program termination to clean-up.  Caller's responsibility not to subsequently call (or use the
+    *        return value from) \c MainWindow::instance().
+    */
+   static void DeleteMainWindow();
+
+   /**
+    * \brief This needs to be called immediately after the constructor.  It does the remaining initialisation of the
+    *        object.  This function cannot be called from the constructor as, in certain circumstances, it will invoke
+    *        code that calls Application::mainWindow() which returns a pointer to the MainWindow and therefore needs the
+    *        MainWindow constructor to have returned!
+    */
+   void init();
+
    //! \brief Get the currently observed recipe.
    Recipe* currentRecipe();
    //! \brief Display a file dialog for writing xml files.
@@ -119,13 +147,13 @@ public slots:
    void changed(QMetaProperty,QVariant);
 
    void treeActivated(const QModelIndex &index);
-   //! \brief Set recipe given an QModelIndex
-   void setRecipe(const QModelIndex &index);
    //! \brief View the given recipe.
    void setRecipe(Recipe* recipe);
 
    //! \brief Update Recipe name to that given by the relevant widget.
    void updateRecipeName();
+   //! \brief Redisplay the OG, FG, etc ranges for the style of the current recipe.  Needs to be called whenever the recipe style is changed.
+   void displayRangesEtcForCurrentRecipeStyle();
    //! \brief Update Recipe Style to that given by the relevant widget.
    void updateRecipeStyle();
    //! \brief Update Recipe Equipment to that given by the relevant widget.
@@ -141,10 +169,13 @@ public slots:
    //! \brief Update Recipe's mash
    void updateRecipeMash();
 
-   //! \brief Close a brewnote tab if we must
-   void closeBrewNote(BrewNote*);
+   //! \brief Update the main windows statusbar.
+   void updateStatus(const QString status);
+
+   //! \brief Close a brewnote tab if we must (because of the BrewNote being deleted)
+   void closeBrewNote(int brewNoteId, std::shared_ptr<QObject> object);
    //! \brief Add given Fermentable to the Recipe.
-   void addFermentableToRecipe(Fermentable* ferm);
+   void addFermentableToRecipe(std::shared_ptr<Fermentable> ferm);
    //! \brief Remove selected Fermentable(s) from the Recipe.
    void removeSelectedFermentable();
    //! \brief Edit selected Fermentable.
@@ -154,28 +185,30 @@ public slots:
    void showPitchDialog();
 
    //! \brief Add given Hop to the Recipe.
-   void addHopToRecipe(Hop *hop);
+   void addHopToRecipe(std::shared_ptr<Hop> hop);
    //! \brief Remove selected Hop(s) from the Recipe.
    void removeSelectedHop();
    //! \brief Edit selected Hop.
    void editSelectedHop();
 
    //! \brief Add given Misc to the Recipe.
-   void addMiscToRecipe(Misc* misc);
+   void addMiscToRecipe(std::shared_ptr<Misc> misc);
    //! \brief Remove selected Misc(s) from the Recipe.
    void removeSelectedMisc();
    //! \brief Edit selected Misc.
    void editSelectedMisc();
 
    //! \brief Add given Yeast to the Recipe.
-   void addYeastToRecipe(Yeast* yeast);
+   void addYeastToRecipe(std::shared_ptr<Yeast> yeast);
    //! \brief Remove selected Yeast(s) from the Recipe.
    void removeSelectedYeast();
    //! \brief Edit selected Yeast
    void editSelectedYeast();
 
-   //! \brief Add a new mash step to the recipe.
+   //! \brief Invoke the pop-up Window to add a new mash step to (the mash of) the recipe.
    void addMashStep();
+   //! \brief Actually add the new mash step to (the mash of) the recipe (in an undoable way).
+   void addMashStepToMash(std::shared_ptr<MashStep> mashStep);
    //! \brief Move currently selected mash step down.
    void moveSelectedMashStepUp();
    //! \brief Move currently selected mash step up.
@@ -185,7 +218,7 @@ public slots:
    //! \brief Edit currently selected mash step.
    void editSelectedMashStep();
    //! \brief Set the current recipe's mash to the one selected in the mash combo box.
-   void setMashToCurrentlySelected();
+   //void setMashToCurrentlySelected();
    //! \brief Save the current recipe's mash to be used in other recipes.
    void saveMash();
    //! \brief Remove the current mash from the recipe, and replace with a blank one.
@@ -200,25 +233,27 @@ public slots:
    //! \brief Create a duplicate of the current recipe.
    void copyRecipe();
 
+   //! \brief Implements "> Edit > Undo"
+   void editUndo();
+   //! \brief Implements "> Edit > Redo"
+   void editRedo();
+
    //! \brief Create a new folder
    void newFolder();
    void renameFolder();
-   // void deleteFolder();
 
    void deleteSelected();
    void copySelected();
    void exportSelected();
 
-   //! \brief Prints the right thing, depending on the signal sender.
-   void print();
-   //! \brief saves the database, which will have some interesting
-   //implications later
-   void save();
    //! \brief Backup the database.
    void backup();
    //! \brief Restore the database.
    void restoreFromBackup();
 
+   //! \brief makes sure we can do water chemistry before we show the window
+   void popChemistry();
+
    //! \brief draws a context menu, the exact nature of which depends on which
    //tree is focused
    void contextMenu(const QPoint &point);
@@ -235,18 +270,14 @@ public slots:
    //! \brief Open the default browser to view Brewtarget manual.
     void openManual();
 
-   //! \brief Merges two database files.
-   void updateDatabase();
-
-   //! \brief Catches a QNetworkReply signal and gets info about any new version available.
-   void finishCheckingVersion();
-
-   void redisplayLabel(Unit::unitDisplay oldUnit, Unit::unitScale oldScale);
+   void redisplayLabel();
 
    void showEquipmentEditor();
    void showStyleEditor();
 
-   //! \brief Set the equipment based on a drop event
+   void updateEquipmentButton();
+
+   //! \brief Set all the things based on a drop event
    void droppedRecipeEquipment(Equipment *kit);
    void droppedRecipeStyle(Style *style);
    void droppedRecipeFermentable(QList<Fermentable*>ferms);
@@ -254,6 +285,26 @@ public slots:
    void droppedRecipeMisc(QList<Misc*>miscs);
    void droppedRecipeYeast(QList<Yeast*>yeasts);
 
+   void versionedRecipe(Recipe* descendant);
+
+   //! \brief Doing updates via this method makes them undoable (and redoable).  This is the most generic version
+   //         which requires the caller to construct a QUndoCommand.
+   void doOrRedoUpdate(QUndoCommand * update);
+
+    //! \brief to lock or not was never the question before now.
+   void lockRecipe(int state);
+   //! \brief prepopulate the ancestorDialog when the menu is selected
+   void setAncestor();
+
+public:
+   //! \brief Doing updates via this method makes them undoable (and redoable).  This is the simplified version
+   //         which suffices for modifications to most individual non-relational attributes.
+   void doOrRedoUpdate(QObject & updatee,
+                       BtStringConst const & propertyName,
+                       QVariant newValue,
+                       QString const & description,
+                       QUndoCommand * parent = nullptr);
+
 protected:
    virtual void closeEvent(QCloseEvent* event);
 
@@ -266,17 +317,40 @@ private slots:
     *
     * \param prop Not yet used. Will indicate which Recipe property has changed.
     */
-   void showChanges(QMetaProperty* prop = 0);
+   void showChanges(QMetaProperty* prop = nullptr);
+
+   //! \brief Set whether undo / redo commands are enabled
+   void setUndoRedoEnable();
 
 private:
+   // Private implementation details - see https://herbsutter.com/gotw/_100/
+   class impl;
+   std::unique_ptr<impl> pimpl;
+
+   //! No copy constructor, as never want anyone, not even our friends, to make copies of a singleton
+   MainWindow(MainWindow const&) = delete;
+   //! No assignment operator , as never want anyone, not even our friends, to make copies of a singleton.
+   MainWindow& operator=(MainWindow const&) = delete;
+   //! No move constructor
+   MainWindow(MainWindow &&) = delete;
+   //! No move assignment
+   MainWindow & operator=(MainWindow &&) = delete;
+
+   void removeHop(std::shared_ptr<Hop> itemToRemove);
+   void removeFermentable(std::shared_ptr<Fermentable> itemToRemove);
+   void removeMisc(std::shared_ptr<Misc> itemToRemove);
+   void removeYeast(std::shared_ptr<Yeast> itemToRemove);
+   void removeMashStep(std::shared_ptr<MashStep> itemToRemove);
+
    Recipe* recipeObs;
+   // TBD: (MY 2020-11-24) Not sure whether we need to store recipe style (since it ought to be available from the
+   //      recipe) or whether this is just for convenience.
    Style* recStyle;
    Equipment* recEquip;
 
    QString highSS, lowSS, goodSS, boldSS; // Palette replacements
 
    AboutDialog* dialog_about;
-   QFileDialog* fileOpener;
    QFileDialog* fileSaver;
    QList<QMenu*> contextMenus;
    EquipmentEditor* equipEditor;
@@ -298,9 +372,12 @@ private:
    QDialog* brewDayDialog;
    ScaleRecipeTool* recipeScaler;
    RecipeFormatter* recipeFormatter;
+   PrintAndPreviewDialog* printAndPreviewDialog;
    OgAdjuster* ogAdjuster;
    ConverterTool* converterTool;
-   TimerListDialog* timerListDialog;
+   HydrometerTool* hydrometerTool;
+   AlcoholTool* alcoholTool;
+   TimerMainDialog* timerMainDialog;
    PrimingDialog* primingDialog;
    StrikeWaterDialog* strikeWaterDialog;
    RefractoDialog* refractoDialog;
@@ -308,19 +385,30 @@ private:
    PitchDialog* pitchDialog;
    QPrinter *printer;
 
+   WaterDialog* waterDialog;
+   WaterEditor* waterEditor;
+
+   AncestorDialog* ancestorDialog;
+
+   // all things tables should go here.
    FermentableTableModel* fermTableModel;
-   FermentableSortFilterProxyModel* fermTableProxy;
    HopTableModel* hopTableModel;
-   HopSortFilterProxyModel* hopTableProxy;
-   MiscTableModel* miscTableModel;
-   MiscSortFilterProxyModel* miscTableProxy;
-   YeastTableModel* yeastTableModel;
-   YeastSortFilterProxyModel* yeastTableProxy;
    MashStepTableModel* mashStepTableModel;
+   MiscTableModel* miscTableModel;
+   YeastTableModel* yeastTableModel;
+
+   // all things lists should go here
    EquipmentListModel* equipmentListModel;
    MashListModel* mashListModel;
    StyleListModel* styleListModel;
+//   WaterListModel* waterListModel;  Appears to be unused...
+
+   // all things sort/filter proxy go here
+   FermentableSortFilterProxyModel* fermTableProxy;
+   HopSortFilterProxyModel* hopTableProxy;
+   MiscSortFilterProxyModel* miscTableProxy;
    StyleSortFilterProxyModel* styleProxyModel;
+   YeastSortFilterProxyModel* yeastTableProxy;
 
    NamedMashEditor* namedMashEditor;
    NamedMashEditor* singleNamedMashEditor;
@@ -328,6 +416,12 @@ private:
    BtDatePopup* btDatePopup;
    int confirmDelete;
 
+   // Undo / Redo, using the Qt Undo framework
+   QUndoStack * undoStack = nullptr;
+
+   //! \brief Fix pixel dimensions according to dots-per-inch (DPI) of screen we're on.
+   void setSizesInPixelsBasedOnDpi();
+
    //! \brief Currently highlighted fermentable in the fermentable table.
    Fermentable* selectedFermentable();
    //! \brief Currently highlighted hop in the hop table.
@@ -345,15 +439,46 @@ private:
 
    //! \brief Set the keyboard shortcuts.
    void setupShortCuts();
-   //! \brief Set the context menus.
+   //! \brief Set the BtTreeView context menus.
    void setupContextMenu();
+   //! \brief Create the CSS strings
+   void setupCSS();
+   //! \brief Create the dialogs, including the file dialogs
+   void setupDialogs();
+   //! \brief Configure the range sliders
+   void setupRanges();
+   //! \brief Configure combo boxes and their list models
+   void setupComboBoxes();
+   //! \brief Configure the tables and their proxies
+   void setupTables();
+   //! \brief Restore any saved states
+   void restoreSavedState();
+   //! \brief Connect the signal/slots for actions
+   void setupTriggers();
+   //! \brief Connect signal/slots for buttons
+   void setupClicks();
+   //! \brief Connect signal/slots for combo boxes
+   void setupActivate();
+   //! \brief Connect signal/slots for combo boxes
+   void setupLabels();
+   //! \brief Connect signal/slots for text edits
+   void setupTextEdit();
+   //! \brief Connect signal/slots drag/drop
+   void setupDrops();
+   //! \brief Connect signal/slots for check boxes
+   void setUpStateChanges();
 
-   void updateDensitySlider(QString attribute, RangedSlider* slider, double max);
-   void updateColorSlider(QString attribute, RangedSlider* slider);
+   void updateDensitySlider(BtStringConst const & propertyNameMin,
+                            BtStringConst const & propertyNameMax,
+                            BtStringConst const & propertyNameCurrent,
+                            RangedSlider* slider,
+                            double max);
+   void updateColorSlider(BtStringConst const & propertyNameMin,
+                          BtStringConst const & propertyNameMax,
+                          BtStringConst const & propertyNameCurrent,
+                          RangedSlider* slider);
 
    void convertedMsg();
-   void importMsg();
 };
 
-#endif   /* _MAINWINDOW_H */
-
+#endif
