@@ -1,6 +1,7 @@
 /*
  * MashEditor.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -17,8 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-#ifndef _MASHEDITOR_H
-#define   _MASHEDITOR_H
+#ifndef MASHEDITOR_H
+#define MASHEDITOR_H
 
 class MashEditor;
 
@@ -34,15 +35,15 @@ class Equipment;
 
 /*!
  * \class MashEditor
- * \author Philip G. Lee
  *
  * \brief View/controller dialog for editing a mash.
+ *
+ *        See also \c NamedMashEditor
  */
-class MashEditor : public QDialog, public Ui::mashEditor
-{
+class MashEditor : public QDialog, public Ui::mashEditor {
    Q_OBJECT
 public:
-   MashEditor( QWidget *parent = 0 );
+   MashEditor( QWidget *parent = nullptr );
 
 public slots:
    void showEditor();
@@ -52,16 +53,16 @@ public slots:
    void fromEquipment();
    //! Set the mash we wish to view/edit.
    void setMash(Mash* mash);
-   void setEquipment(Equipment* e);
+   void setRecipe(Recipe* r);
 
    void changed(QMetaProperty,QVariant);
 private:
-   void showChanges(QMetaProperty* prop = 0);
+   void showChanges(QMetaProperty* prop = nullptr);
    void clear();
+   Recipe* m_rec;
    Mash* mashObs;
-   Equipment* equip;
+   Equipment* m_equip;
 
 };
 
-#endif   /* _MASHEDITOR_H */
-
+#endif
