@@ -1,6 +1,7 @@
 /*
  * MashListModel.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  * - swstim <swstim@gmail.com>
@@ -18,62 +19,68 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 #include "MashListModel.h"
-#include "style.h"
-#include "database.h"
-#include "recipe.h"
-#include "mash.h"
 
-MashListModel::MashListModel(QWidget* parent)
-   : QAbstractListModel(parent), recipe(0)
-{
-   connect( &(Database::instance()), SIGNAL(newMashSignal(Mash*)), this, SLOT(addMash(Mash*)) );
-   connect( &(Database::instance()), SIGNAL(deletedMashSignal(Mash*)), this, SLOT(removeMash(Mash*)) );
-   repopulateList();
+#include <QWidget>
+
+#include "database/ObjectStoreWrapper.h"
+#include "model/Mash.h"
+#include "model/Recipe.h"
+#include "model/Style.h"
+
+MashListModel::MashListModel(QWidget* parent) :
+   QAbstractListModel(parent),
+   recipe(0) {
+   connect(&ObjectStoreTyped<Mash>::getInstance(), &ObjectStoreTyped<Mash>::signalObjectInserted, this, &MashListModel::addMash);
+   connect(&ObjectStoreTyped<Mash>::getInstance(), &ObjectStoreTyped<Mash>::signalObjectDeleted,  this, &MashListModel::removeMash);
+   this->repopulateList();
+   return;
 }
 
-void MashListModel::addMash(Mash* m)
-{
-   if( !m || !m->display() || m->deleted() )
+void MashListModel::addMash(int mashId) {
+   qDebug() << Q_FUNC_INFO << "New mash #" << mashId;
+   Mash* m = ObjectStoreWrapper::getByIdRaw<Mash>(mashId);
+   if (!m || !m->display() || m->deleted()) {
       return;
-   
-   if( !mashes.contains(m) )
-   {
+   }
+
+   if ( !mashes.contains(m) ) {
       int size = mashes.size();
       beginInsertRows( QModelIndex(), size, size );
       mashes.append(m);
-      connect( m, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(mashChanged(QMetaProperty,QVariant)) );
+      connect( m, &NamedEntity::changed, this, &MashListModel::mashChanged );
       endInsertRows();
    }
+   return;
 }
 
 void MashListModel::addMashes(QList<Mash*> m)
 {
    QList<Mash*>::iterator i;
    QList<Mash*> tmp;
-   
+
    for( i = m.begin(); i != m.end(); i++ )
    {
       if( !mashes.contains(*i) && (*i)->display() && ! (*i)->deleted())
          tmp.append(*i);
    }
-   
+
    int size = mashes.size();
    if (size+tmp.size())
    {
       beginInsertRows( QModelIndex(), size, size+tmp.size()-1 );
       mashes.append(tmp);
-      
+
       for( i = tmp.begin(); i != tmp.end(); i++ )
-         connect( *i, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(mashChanged(QMetaProperty,QVariant)) );
-      
+         connect( *i, &NamedEntity::changed, this, &MashListModel::mashChanged );
+
       endInsertRows();
    }
 }
 
-void MashListModel::removeMash(Mash* mash)
-{
+void MashListModel::removeMash(int mashId, std::shared_ptr<QObject> object) {
+
+   Mash* mash = std::static_pointer_cast<Mash>(object).get();
    int ndx = mashes.indexOf(mash);
    if( ndx >= 0 )
    {
@@ -96,16 +103,16 @@ void MashListModel::removeAll()
 }
 
 void MashListModel::mashChanged(QMetaProperty prop, QVariant val)
-{   
+{
    Mash* mSend = qobject_cast<Mash*>(sender());
-   
+
    // NOTE: how to get around the issue that the sender might live in
    // a different thread and therefore always cause sSend == 0?
    if( mSend == 0 )
       return;
-   
+
    QString propName(prop.name());
-   if( propName == "name" )
+   if( propName == PropertyNames::NamedEntity::name )
    {
       int ndx = mashes.indexOf(mSend);
       if( ndx >= 0 )
@@ -113,10 +120,9 @@ void MashListModel::mashChanged(QMetaProperty prop, QVariant val)
    }
 }
 
-void MashListModel::repopulateList()
-{
+void MashListModel::repopulateList() {
    removeAll();
-   addMashes( Database::instance().mashs() );
+   addMashes( ObjectStoreTyped<Mash>::getInstance().getAllRaw() );
 }
 
 Mash* MashListModel::at(int ndx)
