@@ -1,6 +1,7 @@
 /*
  * MashWizard.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  * - Rob Taylor <robtaylor@floopily.org>
  *
@@ -17,39 +18,44 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#ifndef MASHWIZARD_H
+#define MASHWIZARD_H
+#pragma once
 
-#ifndef _MASHWIZARD_H
-#define _MASHWIZARD_H
-
-class MashWizard;
+#include <QDialog>
 
 #include "ui_mashWizard.h"
-#include <QDialog>
-#include "recipe.h"
-#include "unit.h"
+#include "measurement/Unit.h"
+#include "model/Recipe.h"
 
 /*!
  * \class MashWizard
- * \author Philip G. Lee
  *
  * \brief View/controller dialog that helps you design a mash.
  */
-class MashWizard : public QDialog, public Ui::mashWizard
-{
+class MashWizard : public QDialog, public Ui::mashWizard {
    Q_OBJECT
 public:
-   MashWizard(QWidget* parent=0);
+   MashWizard(QWidget* parent=nullptr);
    //! Set the recipe to do mash wizardry on.
    void setRecipe(Recipe* rec);
 
 public slots:
    void wizardry(); // Do what the wizard is supposed to do.
    void show();
+   void toggleSpinBox(QAbstractButton* button);
 
 private:
    Recipe* recObs;
-   Unit *weightUnit;
-   Unit *volumeUnit;
+   Measurement::Unit const * weightUnit;
+   Measurement::Unit const * volumeUnit;
+
+   //!brief just need a holder for the three buttons
+   QButtonGroup* bGroup;
+
+   //!brief helper method to calculate the volume of a decocation step
+   double calcDecoctionAmount( MashStep* step, Mash* mash, double waterMass, double grainMass, double lastTemp, double boiling);
+
 };
 
-#endif   /* _MASHWIZARD_H */
+#endif
