@@ -1,6 +1,7 @@
 /*
  * MiscDialog.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2015
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -17,20 +18,22 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include "MiscDialog.h"
 
-#include <QWidget>
 #include <QDialog>
 #include <QInputDialog>
-#include <QString>
 #include <QList>
-#include "MiscDialog.h"
-#include "database.h"
-#include "recipe.h"
+#include <QString>
+#include <QWidget>
+
+//#include "database/Database.h"
+#include "database/ObjectStoreWrapper.h"
+#include "model/Recipe.h"
 #include "MainWindow.h"
-#include "misc.h"
+#include "model/Misc.h"
 #include "MiscEditor.h"
-#include "MiscTableModel.h"
 #include "MiscSortFilterProxyModel.h"
+#include "tableModels/MiscTableModel.h"
 
 MiscDialog::MiscDialog(MainWindow* parent) :
    QDialog(parent),
@@ -49,13 +52,13 @@ MiscDialog::MiscDialog(MainWindow* parent) :
    tableWidget->sortByColumn( MISCNAMECOL, Qt::AscendingOrder );
    miscTableProxy->setDynamicSortFilter(true);
    miscTableProxy->setFilterKeyColumn(1);
-   
+
    connect( pushButton_addToRecipe, SIGNAL( clicked() ), this, SLOT( addMisc() ) );
    connect( pushButton_new, SIGNAL(clicked()), this, SLOT( newMisc() ) );
-   connect( pushButton_edit, SIGNAL(clicked()), this, SLOT(editSelected()) );
-   connect( pushButton_remove, SIGNAL(clicked()), this, SLOT(removeMisc()) );
-   connect( tableWidget, SIGNAL(doubleClicked(const QModelIndex&)), this, SLOT( addMisc(const QModelIndex&) ) );
-   connect( qLineEdit_searchBox, SIGNAL(textEdited(QString)), this, SLOT(filterMisc(QString)));
+   connect( pushButton_edit, &QAbstractButton::clicked, this, &MiscDialog::editSelected );
+   connect( pushButton_remove, &QAbstractButton::clicked, this, &MiscDialog::removeMisc );
+   connect( tableWidget, &QAbstractItemView::doubleClicked, this, &MiscDialog::addMisc );
+   connect( qLineEdit_searchBox, &QLineEdit::textEdited, this, &MiscDialog::filterMisc);
 
    miscTableModel->observeDatabase(true);
 }
@@ -134,14 +137,15 @@ void MiscDialog::removeMisc()
          return;
    }
 
-   Misc* m = miscTableModel->getMisc(miscTableProxy->mapToSource(selected[0]).row());
-   Database::instance().remove(m);
+   auto m = miscTableModel->getRow(miscTableProxy->mapToSource(selected[0]).row());
+   ObjectStoreWrapper::softDelete(*m);
+   return;
 }
 
 void MiscDialog::addMisc(const QModelIndex& index)
 {
    QModelIndex translated;
-   
+
    if( !index.isValid() )
    {
       QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
@@ -158,8 +162,8 @@ void MiscDialog::addMisc(const QModelIndex& index)
          if( selected[i].row() != row )
             return;
       }
-     
-      // Always need to translate indices through the proxy 
+
+      // Always need to translate indices through the proxy
       translated = miscTableProxy->mapToSource(selected[0]);
    }
    else
@@ -172,10 +176,10 @@ void MiscDialog::addMisc(const QModelIndex& index)
       else
          return;
    }
-   
-   Misc *misc = miscTableModel->getMisc(translated.row());
-   
-   Database::instance().addToRecipe( mainWindow->currentRecipe(), misc );
+
+   MainWindow::instance().addMiscToRecipe(miscTableModel->getRow(translated.row()));
+
+   return;
 }
 
 void MiscDialog::editSelected()
@@ -195,20 +199,28 @@ void MiscDialog::editSelected()
          return;
    }
 
-   Misc* m = miscTableModel->getMisc(miscTableProxy->mapToSource(selected[0]).row());
-   miscEdit->setMisc(m);
+   auto m = miscTableModel->getRow(miscTableProxy->mapToSource(selected[0]).row());
+   miscEdit->setMisc(m.get());
    miscEdit->show();
+   return;
 }
 
 void MiscDialog::newMisc()
+{
+   newMisc(QString());
+}
+
+void MiscDialog::newMisc(QString folder)
 {
    QString name = QInputDialog::getText(this, tr("Misc name"),
                                               tr("Misc name:"));
    if(name.isEmpty())
       return;
 
-   Misc* m = Database::instance().newMisc();
-   m->setName(name);
+   Misc* m = new Misc(name);
+   if ( ! folder.isEmpty() )
+      m->setFolder(folder);
+
    miscEdit->setMisc(m);
    miscEdit->show();
 }
