@@ -1,7 +1,8 @@
 /*
  * MiscDialog.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2015
+ * authors 2009-2021
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -17,9 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _MISCDIALOG_H
-#define _MISCDIALOG_H
+#ifndef MISCDIALOG_H
+#define MISCDIALOG_H
 
 #include <QWidget>
 #include <QDialog>
@@ -38,7 +38,6 @@ class MiscSortFilterProxyModel;
 
 /*!
  * \class MiscDialog
- * \author Philip G. Lee
  *
  * \brief View/controller dialog for the miscs in the database.
  */
@@ -63,6 +62,7 @@ public:
    QPushButton *pushButton_remove;
    //! @}
 
+   void newMisc(QString folder);
 public slots:
    //! Add the selected misc to the current recipe.
    void addMisc(const QModelIndex& = QModelIndex());
@@ -95,5 +95,4 @@ private:
    void retranslateUi();
 };
 
-#endif   /* _MISCDIALOG_H */
-
+#endif   /* MISCDIALOG_H */
