@@ -1,6 +1,7 @@
 /*
  * MiscSortFilterProxyModel.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -17,17 +18,14 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _MISCSORTFILTERPROXYMODEL_H
-#define _MISCSORTFILTERPROXYMODEL_H
-
-class MiscSortFilterProxyModel;
+#ifndef MISCSORTFILTERPROXYMODEL_H
+#define MISCSORTFILTERPROXYMODEL_H
+#pragma once
 
 #include <QSortFilterProxyModel>
 
 /*!
  * \class MiscSortFilterProxyModel
- * \author Philip G. Lee
  *
  * \brief Proxy model for sorting miscs.
  */
