@@ -1,6 +1,7 @@
 /*
  * NamedMashEditor.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -17,31 +18,29 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#include <QWidget>
-#include <QDebug>
-
-#include "mash.h"
-#include "brewtarget.h"
-#include "unit.h"
-#include "equipment.h"
-#include "recipe.h"
-#include "database.h"
-
 #include "NamedMashEditor.h"
 
-NamedMashEditor::NamedMashEditor(QWidget* parent, MashStepEditor* editor, bool singleMashEditor)
-   : QDialog(parent), mashObs(0)
-{
+#include <QDebug>
+#include <QWidget>
+
+#include "database/ObjectStoreWrapper.h"
+#include "measurement/Unit.h"
+#include "model/Equipment.h"
+#include "model/Mash.h"
+#include "model/Recipe.h"
+
+
+NamedMashEditor::NamedMashEditor(QWidget* parent, MashStepEditor* editor, bool singleMashEditor) :
+   QDialog{parent},
+   mashObs{nullptr} {
    setupUi(this);
 
-   if ( singleMashEditor )
-   {
-      for (int i = 0; i < horizontalLayout_mashs->count(); ++i)
-      {
+   if (singleMashEditor) {
+      for (int i = 0; i < horizontalLayout_mashs->count(); ++i) {
          QWidget* w = horizontalLayout_mashs->itemAt(i)->widget();
-         if (w)
+         if (w) {
             w->setVisible(false);
+         }
       }
       // pushButton_new->setVisible(false);
    }
@@ -64,50 +63,52 @@ NamedMashEditor::NamedMashEditor(QWidget* parent, MashStepEditor* editor, bool s
    connect(equipmentComboBox, SIGNAL(activated(const QString&)), this, SLOT(fromEquipment(const QString&)));
 
    // ok and cancel buttons
-   connect(pushButton_save,           SIGNAL(clicked()), this, SLOT(saveAndClose()) );
-   connect(pushButton_cancel,         SIGNAL(clicked()), this, SLOT(closeEditor()) );
+   connect(pushButton_save,           &QAbstractButton::clicked, this, &NamedMashEditor::saveAndClose );
+   connect(pushButton_cancel,         &QAbstractButton::clicked, this, &NamedMashEditor::closeEditor );
    // new mash step, delete mash step, move mash step up and down
-   connect(pushButton_addMashStep,    SIGNAL(clicked()), this, SLOT(addMashStep()));
-   connect(pushButton_removeMashStep, SIGNAL(clicked()), this, SLOT(removeMashStep()));
-   connect(pushButton_mashUp,         SIGNAL(clicked()), this, SLOT(moveMashStepUp()));
-   connect(pushButton_mashDown,       SIGNAL(clicked()), this, SLOT(moveMashStepDown()));
+   connect(pushButton_addMashStep,    &QAbstractButton::clicked, this, &NamedMashEditor::addMashStep);
+   connect(pushButton_removeMashStep, &QAbstractButton::clicked, this, &NamedMashEditor::removeMashStep);
+   connect(pushButton_mashUp,         &QAbstractButton::clicked, this, &NamedMashEditor::moveMashStepUp);
+   connect(pushButton_mashDown,       &QAbstractButton::clicked, this, &NamedMashEditor::moveMashStepDown);
    // finally, the combo box and the remove mash button
    connect(mashComboBox, SIGNAL(activated(const QString&)), this, SLOT(mashSelected(const QString&)));
-   connect(pushButton_remove, SIGNAL(clicked()), this, SLOT(removeMash()));
-
-   setMash(mashListModel->at(mashComboBox->currentIndex()));
+   connect(pushButton_remove, &QAbstractButton::clicked, this, &NamedMashEditor::removeMash);
 
+   this->setMash(mashListModel->at(mashComboBox->currentIndex()));
+   return;
 }
 
-void NamedMashEditor::showEditor()
-{
-   showChanges();
-   setVisible(true);
+void NamedMashEditor::showEditor() {
+   this->showChanges();
+   this->setVisible(true);
+   return;
 }
 
-void NamedMashEditor::closeEditor()
-{
-   setVisible(false);
+void NamedMashEditor::closeEditor() {
+   this->setVisible(false);
 }
 
-void NamedMashEditor::saveAndClose()
-{
-   if( mashObs == 0 )
+void NamedMashEditor::saveAndClose() {
+   if (this->mashObs == nullptr) {
       return;
+   }
+
+   qDebug() << Q_FUNC_INFO << "Saving mash (#" << this->mashObs->key() << ")";
 
    // using toSI aon the spargePh is something of a cheat, but the btLineEdit
    // class will do the right thing. That is how a plan comes together.
 
-   mashObs->setEquipAdjust( true ); // BeerXML won't like me, but it's just stupid not to adjust for the equipment when you're able.
-   mashObs->setName( lineEdit_name->text() );
-   mashObs->setGrainTemp_c(lineEdit_grainTemp->toSI());
-   mashObs->setSpargeTemp_c(lineEdit_spargeTemp->toSI());
-   mashObs->setPh(lineEdit_spargePh->toSI()); 
-   mashObs->setTunTemp_c(lineEdit_tunTemp->toSI());
-   mashObs->setTunWeight_kg(lineEdit_tunMass->toSI());
-   mashObs->setTunSpecificHeat_calGC(lineEdit_tunSpHeat->toSI());
+   this->mashObs->setEquipAdjust(true); // BeerXML won't like me, but it's just stupid not to adjust for the equipment when you're able.
+   this->mashObs->setName(lineEdit_name->text());
+   this->mashObs->setGrainTemp_c(lineEdit_grainTemp->toSI().quantity);
+   this->mashObs->setSpargeTemp_c(lineEdit_spargeTemp->toSI().quantity);
+   this->mashObs->setPh(lineEdit_spargePh->toSI().quantity);
+   this->mashObs->setTunTemp_c(lineEdit_tunTemp->toSI().quantity);
+   this->mashObs->setTunWeight_kg(lineEdit_tunMass->toSI().quantity);
+   this->mashObs->setTunSpecificHeat_calGC(lineEdit_tunSpHeat->toSI().quantity);
 
-   mashObs->setNotes( textEdit_notes->toPlainText() );
+   this->mashObs->setNotes( textEdit_notes->toPlainText() );
+   return;
 }
 
 void NamedMashEditor::setMash(Mash* mash)
@@ -120,7 +121,7 @@ void NamedMashEditor::setMash(Mash* mash)
 
    if( mashObs )
    {
-      connect( mashObs, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(changed(QMetaProperty,QVariant)) );
+      connect( mashObs, &NamedEntity::changed, this, &NamedMashEditor::changed );
       showChanges();
    }
 }
@@ -131,58 +132,58 @@ void NamedMashEditor::changed(QMetaProperty prop, QVariant /*val*/)
       showChanges(&prop);
 }
 
-void NamedMashEditor::showChanges(QMetaProperty* prop)
-{
+void NamedMashEditor::showChanges(QMetaProperty* prop) {
    bool updateAll = false;
    QString propName;
 
-   if( mashObs == 0 )
-   {
-      clear();
+   if (this->mashObs == nullptr) {
+      this->clear();
       return;
    }
 
-   if( prop == 0 )
+   if (prop == nullptr) {
       updateAll = true;
-   else
+   } else {
       propName = prop->name();
+   }
+   qDebug() << Q_FUNC_INFO << "Updating" << (updateAll ? "all" : "property") << propName;
 
-   if( propName == "name" || updateAll ) {
+   if( propName == PropertyNames::NamedEntity::name || updateAll ) {
       lineEdit_name->setText(mashObs->name());
       if( ! updateAll )
          return;
    }
-   if( propName == "grainTemp_c" || updateAll ) {
+   if( propName == PropertyNames::Mash::grainTemp_c || updateAll ) {
       lineEdit_grainTemp->setText(mashObs);
       if( ! updateAll )
          return;
    }
-   if( propName == "spargeTemp_c" || updateAll ) {
+   if( propName == PropertyNames::Mash::spargeTemp_c || updateAll ) {
       lineEdit_spargeTemp->setText(mashObs);
       if( ! updateAll )
          return;
    }
-   if( propName == "ph" || updateAll ) {
+   if( propName == PropertyNames::Mash::ph || updateAll ) {
       lineEdit_spargePh->setText(mashObs);
       if( ! updateAll )
          return;
    }
-   if( propName == "tunTemp_c" || updateAll ) {
+   if( propName == PropertyNames::Mash::tunTemp_c || updateAll ) {
       lineEdit_tunTemp->setText(mashObs);
       if( ! updateAll )
          return;
    }
-   if( propName == "tunMass_kg" || updateAll ) {
+   if( propName == PropertyNames::Mash::tunWeight_kg || updateAll ) {
       lineEdit_tunMass->setText(mashObs);
       if( ! updateAll )
          return;
    }
-   if( propName == "tunSpecificHeat_calGC" || updateAll ) {
+   if( propName == PropertyNames::Mash::tunSpecificHeat_calGC || updateAll ) {
       lineEdit_tunSpHeat->setText(mashObs);
       if( ! updateAll )
          return;
    }
-   if( propName == "notes" || updateAll ) {
+   if( propName == PropertyNames::Mash::notes || updateAll ) {
       textEdit_notes->setPlainText(mashObs->notes());
       if( ! updateAll )
          return;
@@ -203,14 +204,17 @@ void NamedMashEditor::clear()
 
 }
 
-void NamedMashEditor::addMashStep()
-{
-   if ( ! mashObs )
+void NamedMashEditor::addMashStep() {
+   if (!this->mashObs) {
       return;
+   }
 
-   MashStep* step = Database::instance().newMashStep(mashObs);
+   // The call to Mash::addMashStep() will also store the MashStep in the ObjectStore / DB
+   auto step = std::make_shared<MashStep>();
+   this->mashObs->addMashStep(step);
    mashStepEditor->setMashStep(step);
    mashStepEditor->setVisible(true);
+   return;
 }
 
 bool NamedMashEditor::justOne(QModelIndexList selected)
@@ -230,8 +234,7 @@ bool NamedMashEditor::justOne(QModelIndexList selected)
    return true;
 }
 
-void NamedMashEditor::removeMashStep()
-{
+void NamedMashEditor::removeMashStep() {
    if ( ! mashObs )
       return;
 
@@ -239,34 +242,43 @@ void NamedMashEditor::removeMashStep()
    if ( !justOne(selected) )
       return;
 
-   MashStep* step = mashStepTableModel->getMashStep(selected[0].row());
-   Database::instance().removeFrom(mashObs, step);
+   auto step = mashStepTableModel->getRow(selected[0].row());
+   this->mashObs->removeMashStep(step);
+   return;
 }
 
 void NamedMashEditor::moveMashStepUp()
 {
    QModelIndexList selected = mashStepTableWidget->selectionModel()->selectedIndexes();
+   if (selected.isEmpty())
+   {  //nothing selected
+      return;
+   }
+
    int row = selected[0].row();
 
    if ( ! justOne(selected) || row < 1)
       return;
 
-   MashStep* m1 = mashStepTableModel->getMashStep(row);
-   MashStep* m2 = mashStepTableModel->getMashStep(row-1);
-   Database::instance().swapMashStepOrder(m1,m2);
+   mashStepTableModel->moveStepUp(row);
+   return;
 }
 
 void NamedMashEditor::moveMashStepDown()
 {
    QModelIndexList selected = mashStepTableWidget->selectionModel()->selectedIndexes();
+   if (selected.isEmpty())
+   {  //nothing selected
+      return;
+   }
+
    int row = selected[0].row();
 
    if ( ! justOne(selected) || row >= mashStepTableModel->rowCount()-1 )
       return;
 
-   MashStep* m1 = mashStepTableModel->getMashStep(row);
-   MashStep* m2 = mashStepTableModel->getMashStep(row+1);
-   Database::instance().swapMashStepOrder(m1,m2);
+   mashStepTableModel->moveStepDown(row);
+   return;
 }
 
 void NamedMashEditor::mashSelected(const QString& name)
@@ -289,19 +301,24 @@ void NamedMashEditor::fromEquipment(const QString& name)
    }
 }
 
-void NamedMashEditor::removeMash()
-{
-   if ( ! mashObs )
+void NamedMashEditor::removeMash() {
+   if (!this->mashObs) {
       return;
+   }
 
-   int newMash = mashComboBox->currentIndex() - 1;
+   int newMash = this->mashComboBox->currentIndex() - 1;
 
    // I *think* we want to disconnect the mash first?
-   disconnect(mashObs, 0, this, 0);
+   disconnect(this->mashObs, 0, this, 0);
    // Delete the mashsteps
-   QList<MashStep*> steps = mashObs->mashSteps();
-   Database::instance().remove(steps);
-   // and delete the mash itself
-   Database::instance().remove(mashObs);
-   setMash(mashListModel->at(newMash));
+   // .:TBD:. Mash should be responsible for deleting its steps.  This is already correctly handled for hard delete, but
+   // not for soft delete.
+   for (auto step : this->mashObs->mashSteps()) {
+      ObjectStoreWrapper::softDelete(*step);
+   }
+   // Delete the mash itself
+   ObjectStoreWrapper::softDelete(*this->mashObs);
+
+   this->setMash(this->mashListModel->at(newMash));
+   return;
 }
