@@ -21,11 +21,11 @@
 
 #include <QDialog>
 #include "ui_ogAdjuster.h"
-#include "recipe.h"
+#include "model/Recipe.h"
 
 /*!
  * \class OgAdjuster
- * \author Philip G. Lee
+ *
  *
  * \brief View/controller dialog that helps you correct your OG on brew day.
  */
