@@ -1,7 +1,8 @@
 /*
  * PitchDialog.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
  * - A.J. Drobnich <aj.drobnich@gmail.com>
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -17,16 +18,18 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 #include "PitchDialog.h"
-#include <QChar>
-#include "brewtarget.h"
-#include "Algorithms.h"
-#include "unit.h"
+
 #include <math.h>
 
-PitchDialog::PitchDialog(QWidget* parent) : QDialog(parent)
-{
+#include <QChar>
+
+#include "Algorithms.h"
+#include "Localization.h"
+#include "measurement/Unit.h"
+#include "PersistentSettings.h"
+
+PitchDialog::PitchDialog(QWidget* parent) : QDialog(parent) {
    setupUi(this);
 
    // Set default dates
@@ -34,45 +37,35 @@ PitchDialog::PitchDialog(QWidget* parent) : QDialog(parent)
    dateEdit_ProductionDate->setDate(QDate::currentDate());
    updateViabilityFromDate(QDate::currentDate());
 
-   connect( lineEdit_vol, SIGNAL(textModified()), this, SLOT(calculate()));
-   connect( lineEdit_OG, SIGNAL(textModified()), this, SLOT(calculate()));
-   connect( slider_pitchRate, SIGNAL(valueChanged(int)), this, SLOT(calculate()) );
-   connect( slider_pitchRate, SIGNAL(valueChanged(int)), this, SLOT(updateShownPitchRate(int)) );
-   connect( spinBox_Viability, SIGNAL(valueChanged(int)), this, SLOT(calculate()));
-   connect( spinBox_VialsPitched, SIGNAL(valueChanged(int)), this, SLOT(calculate()));
-   connect( comboBox_AerationMethod, SIGNAL(currentIndexChanged(int)), this, SLOT(calculate()));
-   connect( dateEdit_ProductionDate, SIGNAL(dateChanged(QDate)), this, SLOT(updateViabilityFromDate(QDate)));
-   connect( checkBox_CalculateViability, SIGNAL(stateChanged(int)), this, SLOT(toggleViabilityFromDate(int)));
+   connect(lineEdit_vol,                &BtLineEdit::textModified,                           this, &PitchDialog::calculate);
+   connect(lineEdit_OG,                 &BtLineEdit::textModified,                           this, &PitchDialog::calculate);
+   connect(slider_pitchRate,            &QAbstractSlider::valueChanged,                      this, &PitchDialog::calculate);
+   connect(slider_pitchRate,            &QAbstractSlider::valueChanged,                      this, &PitchDialog::updateShownPitchRate);
+   connect(spinBox_Viability,           QOverload<int>::of(&QSpinBox::valueChanged),         this, &PitchDialog::calculate);
+   connect(spinBox_VialsPitched,        QOverload<int>::of(&QSpinBox::valueChanged),         this, &PitchDialog::calculate);
+   connect(comboBox_AerationMethod,     QOverload<int>::of(&QComboBox::currentIndexChanged), this, &PitchDialog::calculate);
+   connect(dateEdit_ProductionDate,     &QDateTimeEdit::dateChanged,                         this, &PitchDialog::updateViabilityFromDate);
+   connect(checkBox_CalculateViability, &QCheckBox::stateChanged,                            this, &PitchDialog::toggleViabilityFromDate);
 
    // Dates are a little more cranky
-   connect(label_productionDate,SIGNAL(labelChanged(Unit::unitDisplay,Unit::unitScale)),this,SLOT(updateProductionDate(Unit::unitDisplay,Unit::unitScale)));
-   updateProductionDate(Unit::noUnit,Unit::noScale);
+///   connect(label_productionDate,        &BtLabel::changedSystemOfMeasurementOrScale,                  this, &PitchDialog::updateProductionDate);
+   this->updateProductionDate();
    updateShownPitchRate(0);
+   return;
 }
 
-PitchDialog::~PitchDialog()
-{
-}
+PitchDialog::~PitchDialog() = default;
 
-void PitchDialog::updateProductionDate(Unit::unitDisplay dsp, Unit::unitScale scl)
-{
-   QString format;
+void PitchDialog::updateProductionDate() {
    // I need the new unit, not the old
-   Unit::unitDisplay unitDsp = (Unit::unitDisplay)Brewtarget::option("productionDate", Brewtarget::getDateFormat(), "pitchRateCalc", Brewtarget::UNIT).toInt();
-
-   switch(unitDsp)
-   {
-      case Unit::displayUS:
-         format = "MM-dd-yyyy";
-         break;
-      case Unit::displayImp:
-         format = "dd-MM-yyyy";
-         break;
-      case Unit::displaySI:
-      default:
-         format = "yyyy-MM-dd";
-   }
-   dateEdit_ProductionDate->setDisplayFormat(format);
+   // .:TBD:. For the moment, we stick with whatever date format the user has set for the whole program.  Would need to
+   // uncomment the following line and implement the corresponding function in Localization, plus do an appropriate
+   // pop-up menu etc if we want to select date format per-field.
+//   auto dateFormat = Localization::getDateFormatForField(PersistentSettings::Names::productionDate,
+//                                                         PersistentSettings::Sections::pitchRateCalc);
+   auto dateFormat = Localization::getDateFormat();
+   QString format = Localization::numericToStringDateFormat(dateFormat);
+   this->dateEdit_ProductionDate->setDisplayFormat(format);
 }
 
 void PitchDialog::setWortVolume_l(double volume)
@@ -92,8 +85,8 @@ void PitchDialog::calculate()
    double rate_MpermLP = (2-0.75) * ((double)slider_pitchRate->value()) / 100.0 + 0.75;
 
    // This isn't right.
-   double og = lineEdit_OG->toSI();
-   double vol_l = lineEdit_vol->toSI();
+   double og = lineEdit_OG->toSI().quantity;
+   double vol_l = lineEdit_vol->toSI().quantity;
 
    // I somewhat aribtrarily defined "SI" for density to be specific gravity.
    // Since these calcs need plato, convert
@@ -111,7 +104,7 @@ void PitchDialog::calculate()
    switch (comboBox_AerationMethod->currentIndex())
    {
       case 1:   // O2 at the start
-         aerationFactor = 1.33; 
+         aerationFactor = 1.33;
          break;
       case 2:   // Stir plate.
          aerationFactor = 2.66;
