@@ -17,41 +17,36 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#include <QString>
-#include <QDebug>
 #include "RefractoDialog.h"
-#include "Algorithms.h"
-#include "brewtarget.h"
-#include <cmath>
-#include <QMessageBox>
 
-RefractoDialog::RefractoDialog(QWidget* parent) : QDialog(parent)
-{
+#include <cmath>
+
+#include <QDebug>
+#include <QMessageBox>
+#include <QString>
+
+#include "Algorithms.h"
+#include "measurement/Measurement.h"
+
+RefractoDialog::RefractoDialog(QWidget* parent) : QDialog(parent) {
    setupUi(this);
 
-   connect( pushButton_calculate, SIGNAL( clicked() ), this, SLOT( calculate() ) );
+   connect( pushButton_calculate, &QAbstractButton::clicked, this, &RefractoDialog::calculate );
+   return;
 }
 
-RefractoDialog::~RefractoDialog()
-{
-}
+RefractoDialog::~RefractoDialog() = default;
 
-void RefractoDialog::calculate()
-{
+void RefractoDialog::calculate() {
    bool haveCP = true;
    bool haveOP = true;
    bool haveOG = true;
 
-   double originalPlato = lineEdit_op->toDouble(&haveOP);
-   double inputOG       = lineEdit_inputOG->toDouble(&haveOG);
-   double currentPlato  = lineEdit_cp->toDouble(&haveCP);
-   double ri = 0;
-   double og = 0;
-   double sg = 0;
-   double re = 0;
-   double abv = 0;
-   double abw = 0;
+   // User can enter in specific gravity or Plato, but the lineEdit is going to convert it to Plato, so we can just
+   // grab the number
+   double originalPlato = lineEdit_op->toDoubleRaw(&haveOP);
+   double inputOG       = lineEdit_inputOG->toDoubleRaw(&haveOG);
+   double currentPlato  = lineEdit_cp->toDoubleRaw(&haveCP);
 
    clearOutputFields();
 
@@ -59,41 +54,45 @@ void RefractoDialog::calculate()
    // I really dislike just doing nothing as the user is POUNDING on the
    // calculate button, waiting for something to happen. Maybe we should
    // provide some ... oh ... feedback that they are doing something wrong?
-   if( ! haveCP ) {
+   if (!haveCP) {
       return;
    }
 
-   ri = Algorithms::refractiveIndex(currentPlato);
-   lineEdit_ri->setText(Brewtarget::displayAmount(ri));
+   double ri = Algorithms::refractiveIndex(currentPlato);
+   lineEdit_ri->setText(Measurement::displayQuantity(ri, 3));
 
-   if( (!haveOG) && haveOP )
-   {
+   if (!haveOG && haveOP) {
       inputOG = Algorithms::PlatoToSG_20C20C( originalPlato );
       lineEdit_inputOG->setText(inputOG);
-   }
-   else if( (!haveOP) && haveOG )
-   {
+   } else if (!haveOP && haveOG) {
       originalPlato = Algorithms::SG_20C20C_toPlato( inputOG );
       lineEdit_op->setText(inputOG);
-   }
-   else if( (!haveOP) && (!haveOG) ) {
+   } else if (!haveOP && !haveOG) {
       qDebug() << Q_FUNC_INFO << "no plato or og";
       return; // Can't do much if we don't have OG or OP.
    }
 
-   og = Algorithms::PlatoToSG_20C20C( originalPlato );
-   if( originalPlato != currentPlato )
+   double og = Algorithms::PlatoToSG_20C20C( originalPlato );
+   double sg = 0;
+   if (originalPlato != currentPlato) {
      sg = Algorithms::sgByStartingPlato( originalPlato, currentPlato );
-   else
+   } else {
      sg = og;
-   re = Algorithms::realExtract( sg, currentPlato );
-   abv = Algorithms::getABVBySGPlato( sg, currentPlato );
-   abw = Algorithms::getABWBySGPlato( sg, currentPlato );
+   }
+
+   double re = Algorithms::realExtract( sg, currentPlato );
+   double abv = Algorithms::getABVBySGPlato( sg, currentPlato );
+   double abw = Algorithms::getABWBySGPlato( sg, currentPlato );
 
    // Warn the user if the inputOG and calculated og don't match.
-   if( qAbs(og - inputOG) > 0.002 )
-      QMessageBox::warning(this, tr("OG Mismatch"),
-                           tr("Based on the given original plato, the OG should be %1, but you have entered %2. Continuing with the calculated OG.").arg(og,0,'f',3).arg(inputOG,0,'f',3));
+   if( qAbs(og - inputOG) > 0.002 ) {
+      QMessageBox::warning(
+         this,
+         tr("OG Mismatch"),
+         tr("Based on the given original plato, the OG should be %1, but you have entered %2. "
+            "Continuing with the calculated OG.").arg(og,0,'f',3).arg(inputOG,0,'f',3)
+      );
+   }
 
    lineEdit_og->setText(og);
    lineEdit_sg->setText(sg);
@@ -102,14 +101,15 @@ void RefractoDialog::calculate()
    lineEdit_re->setText(Algorithms::PlatoToSG_20C20C(re));
    lineEdit_abv->setText(abv);
    lineEdit_abw->setText(abw);
+   return;
 }
 
-void RefractoDialog::clearOutputFields()
-{
+void RefractoDialog::clearOutputFields() {
    lineEdit_ri->clear();
    lineEdit_og->clear();
    lineEdit_sg->clear();
    lineEdit_re->clear();
    lineEdit_abv->clear();
    lineEdit_abw->clear();
+   return;
 }
