@@ -16,9 +16,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 #ifndef SCALE_RECIPE_TOOL_H
 #define SCALE_RECIPE_TOOL_H
+#pragma once
 
 #include <QDialog>
 #include <QWidget>
@@ -34,7 +34,7 @@
 #include <QLineEdit>
 
 // Forward declarations
-class BeerXMLSortProxyModel;
+class NamedEntitySortProxyModel;
 class Equipment;
 class EquipmentListModel;
 class Recipe;
@@ -45,7 +45,7 @@ class Recipe;
 class ScaleRecipeTool : public QWizard
 {
    Q_OBJECT
-   
+
 public:
    ScaleRecipeTool(QWidget* parent=0);
    //! \brief Set the observed \c Recipe
@@ -62,7 +62,7 @@ private:
    Recipe* recObs;
    QButtonGroup scaleGroup;
    EquipmentListModel* equipListModel;
-   BeerXMLSortProxyModel* equipSortProxyModel;
+   NamedEntitySortProxyModel* equipSortProxyModel;
 };
 
 class ScaleRecipeIntroPage : public QWizardPage {
@@ -120,4 +120,4 @@ private:
    QLineEdit* effLineEdit;
 };
 
-#endif /*SCALE_RECIPE_TOOL_H*/
+#endif
