@@ -1,6 +1,7 @@
 /*
  * StyleButton.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -17,9 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _STYLEBUTTON_H
-#define _STYLEBUTTON_H
+#ifndef STYLEBUTTON_H
+#define STYLEBUTTON_H
 
 #include <QPushButton>
 #include <QMetaProperty>
@@ -32,7 +32,6 @@ class QWidget;
 
 /*!
  * \class StyleButton
- * \author Mik Firestone (mikfire@gmail.com)
  *
  * \brief This is a view class that displays the name of a style
  */
@@ -40,9 +39,9 @@ class StyleButton : public QPushButton
 {
    Q_OBJECT
 public:
-   StyleButton(QWidget* parent = 0);
+   StyleButton(QWidget* parent = nullptr);
    virtual ~StyleButton(){}
-   
+
    //! Observe a recipe's equipment.
    void setRecipe(Recipe* recipe);
    //! Observe a particular equipment.
@@ -53,7 +52,7 @@ private slots:
    void styleChanged(QMetaProperty,QVariant);
 
 private:
-   Recipe* _rec;
+   Recipe* m_rec;
    Style* _style;
 };
 
