@@ -1,6 +1,7 @@
 /*
  * StyleListModel.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  * - swstim <swstim@gmail.com>
  *
@@ -17,60 +18,70 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 #include "StyleListModel.h"
-#include "style.h"
-#include "database.h"
-#include "recipe.h"
 
-StyleListModel::StyleListModel(QWidget* parent)
-   : QAbstractListModel(parent), recipe(0)
-{
-   connect( &(Database::instance()), SIGNAL(newStyleSignal(Style*)), this, SLOT(addStyle(Style*)) );
-   connect( &(Database::instance()), SIGNAL(deletedStyleSignal(Style*)), this, SLOT(removeStyle(Style*)) );
+#include <QAbstractListModel>
+#include <QWidget>
+
+#include "model/Style.h"
+#include "database/ObjectStoreWrapper.h"
+#include "model/Recipe.h"
+
+StyleListModel::StyleListModel(QWidget* parent) :
+   QAbstractListModel(parent),
+   recipe(0) {
+   connect(&ObjectStoreTyped<Style>::getInstance(), &ObjectStoreTyped<Style>::signalObjectInserted, this, &StyleListModel::addStyle);
+   connect(&ObjectStoreTyped<Style>::getInstance(), &ObjectStoreTyped<Style>::signalObjectDeleted,  this, &StyleListModel::removeStyle);
    repopulateList();
+   return;
 }
 
-void StyleListModel::addStyle(Style* s)
-{
+void StyleListModel::addStyle(int styleId) {
+   Style* s = ObjectStoreWrapper::getByIdRaw<Style>(styleId);
    if( !s || !s->display() || s->deleted() )
       return;
-   
+
    if( !styles.contains(s) )
    {
       int size = styles.size();
       beginInsertRows( QModelIndex(), size, size );
       styles.append(s);
-      connect( s, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(styleChanged(QMetaProperty,QVariant)) );
+      connect( s, &NamedEntity::changed, this, &StyleListModel::styleChanged );
       endInsertRows();
    }
+   return;
 }
 
 void StyleListModel::addStyles(QList<Style*> s)
 {
    QList<Style*>::iterator i;
    QList<Style*> tmp;
-   
+
    for( i = s.begin(); i != s.end(); i++ )
    {
       if( !styles.contains(*i) )
          tmp.append(*i);
    }
-   
+
    int size = styles.size();
    if (size+tmp.size())
    {
       beginInsertRows( QModelIndex(), size, size+tmp.size()-1 );
       styles.append(tmp);
-      
+
       for( i = tmp.begin(); i != tmp.end(); i++ )
-         connect( *i, SIGNAL(changed(QMetaProperty,QVariant)), this, SLOT(styleChanged(QMetaProperty,QVariant)) );
-      
+         connect( *i, &NamedEntity::changed, this, &StyleListModel::styleChanged );
+
       endInsertRows();
    }
 }
 
-void StyleListModel::removeStyle(Style* style)
+void StyleListModel::removeStyle(int styleId, std::shared_ptr<QObject> object) {
+   this->remove(std::static_pointer_cast<Style>(object).get());
+   return;
+}
+
+void StyleListModel::remove(Style* style)
 {
    int ndx = styles.indexOf(style);
    if( ndx >= 0 )
@@ -94,16 +105,16 @@ void StyleListModel::removeAll()
 }
 
 void StyleListModel::styleChanged(QMetaProperty prop, QVariant val)
-{   
+{
    Style* sSend = qobject_cast<Style*>(sender());
-   
+
    // NOTE: how to get around the issue that the sender might live in
    // a different thread and therefore always cause sSend == 0?
    if( sSend == 0 )
       return;
-   
+
    QString propName(prop.name());
-   if( propName == "name" )
+   if( propName == PropertyNames::NamedEntity::name )
    {
       int ndx = styles.indexOf(sSend);
       if( ndx >= 0 )
@@ -111,10 +122,10 @@ void StyleListModel::styleChanged(QMetaProperty prop, QVariant val)
    }
 }
 
-void StyleListModel::repopulateList()
-{
+void StyleListModel::repopulateList() {
    removeAll();
-   addStyles( Database::instance().styles() );
+   addStyles( ObjectStoreTyped<Style>::getInstance().getAllRaw() );
+   return;
 }
 
 Style* StyleListModel::at(int ndx)
