@@ -1,7 +1,8 @@
 /*
  * WaterEditor.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2022
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -17,13 +18,16 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
 #ifndef WATEREDITOR_H
 #define WATEREDITOR_H
+#pragma once
+
+#include <memory> // For PImpl
 
 #include <QDialog>
 #include <QMetaProperty>
 #include <QVariant>
+
 #include "ui_waterEditor.h"
 
 // Forward declarations.
@@ -31,29 +35,35 @@ class Water;
 
 /*!
  * \class WaterEditor
- * \author Philip G. Lee
  *
- * \brief View/controller class for modifying water records.
+ * \brief View/controller class for creating and modifying water records.
  */
-class WaterEditor : public QDialog, public Ui::waterEditor
-{
-    Q_OBJECT
+class WaterEditor : public QDialog, public Ui::waterEditor {
+   Q_OBJECT
 public:
-    WaterEditor(QWidget *parent = 0);
-    virtual ~WaterEditor() {}
+   WaterEditor(QWidget *parent = nullptr, QString const editorName = "Unnamed");
+   virtual ~WaterEditor();
 
-    /*!
-     * Sets the water we want to observe.
-     */
-    void setWater(Water* water);
+   /*!
+    * Sets the water we want to observe.
+    *
+    * \param water If \c std::nullopt then stop observing
+    */
+   void setWater(std::optional<std::shared_ptr<Water>> water);
 
- public slots:
-    void showChanges(QMetaProperty* prop = 0);
-    void saveAndClose();
-    void changed(QMetaProperty,QVariant);
+   void newWater(QString folder);
+
+public slots:
+   void showChanges(QMetaProperty const * prop = nullptr);
+   void inputFieldModified();
+   void changed(QMetaProperty, QVariant);
+   void saveAndClose();
+   void clearAndClose();
 
 private:
-    Water* obs; // Observed water.
+   // Private implementation details - see https://herbsutter.com/gotw/_100/
+   class impl;
+   std::unique_ptr<impl> pimpl;
 };
 
-#endif // WATEREDITOR_H
+#endif
