@@ -1,6 +1,7 @@
 /*
  * WaterTableWidget.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -16,9 +17,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _WATERTABLEWIDGET_H
-#define   _WATERTABLEWIDGET_H
+#ifndef WATERTABLEWIDGET_H
+#define WATERTABLEWIDGET_H
 
 class WaterTableWidget;
 
@@ -28,7 +28,7 @@ class WaterTableModel;
 
 /*!
  * \class WaterTableWidget
- * \author Philip G. Lee
+ *
  *
  * \brief Completely redundant class. Remove and just use QTableView.
  */
@@ -44,5 +44,4 @@ private:
    WaterTableModel* model;
 };
 
-#endif   /* _WATERTABLEWIDGET_H */
-
+#endif   //WATERTABLEWIDGET_H
