@@ -1,6 +1,7 @@
 /*
  * YeastDialog.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2015
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -17,19 +18,20 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include "YeastDialog.h"
 
-#include <QWidget>
 #include <QDialog>
 #include <QInputDialog>
-#include <QString>
 #include <QList>
-#include "YeastDialog.h"
-#include "database.h"
-#include "recipe.h"
+#include <QString>
+#include <QWidget>
+
+#include "database/ObjectStoreWrapper.h"
 #include "MainWindow.h"
-#include "yeast.h"
+#include "model/Recipe.h"
+#include "model/Yeast.h"
+#include "tableModels/YeastTableModel.h"
 #include "YeastEditor.h"
-#include "YeastTableModel.h"
 #include "YeastSortFilterProxyModel.h"
 
 YeastDialog::YeastDialog(MainWindow* parent)
@@ -48,11 +50,11 @@ YeastDialog::YeastDialog(MainWindow* parent)
    yeastTableProxy->setFilterKeyColumn(1);
 
    connect( pushButton_addToRecipe, SIGNAL( clicked() ), this, SLOT( addYeast() ) );
-   connect( pushButton_edit, SIGNAL( clicked() ), this, SLOT( editSelected() ) );
+   connect( pushButton_edit, &QAbstractButton::clicked, this, &YeastDialog::editSelected );
    connect( pushButton_new, SIGNAL( clicked() ), this, SLOT( newYeast() ) );
-   connect( pushButton_remove, SIGNAL(clicked()), this, SLOT( removeYeast() ) );
-   connect( tableWidget, SIGNAL(doubleClicked(const QModelIndex&)), this, SLOT( addYeast(const QModelIndex&) ) );
-   connect( qLineEdit_searchBox, SIGNAL(textEdited(QString)), this, SLOT(filterYeasts(QString)));
+   connect( pushButton_remove, &QAbstractButton::clicked, this, &YeastDialog::removeYeast );
+   connect( tableWidget, &QAbstractItemView::doubleClicked, this, &YeastDialog::addYeast );
+   connect( qLineEdit_searchBox, &QLineEdit::textEdited, this, &YeastDialog::filterYeasts);
 
    yeastTableModel->observeDatabase(true);
 
@@ -115,19 +117,16 @@ void YeastDialog::retranslateUi()
 #endif // QT_NO_TOOLTIP
 }
 
-void YeastDialog::removeYeast()
-{
+void YeastDialog::removeYeast() {
    QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
-   QModelIndex translated;
-   int row, size, i;
-
-   size = selected.size();
-   if( size == 0 )
+   int size = selected.size();
+   if( size == 0 ) {
       return;
+   }
 
    // Make sure only one row is selected.
-   row = selected[0].row();
-   for( i = 1; i < size; ++i )
+   int row = selected[0].row();
+   for(int i = 1; i < size; ++i )
    {
       if( selected[i].row() != row )
          return;
@@ -135,15 +134,16 @@ void YeastDialog::removeYeast()
 
    // We need to translate from the view's index to the model's index.  The
    // proxy model does the heavy lifting, as long as we do the call.
-   translated = yeastTableProxy->mapToSource(selected[0]);
-   Yeast *yeast = yeastTableModel->getYeast(translated.row());
-   Database::instance().remove(yeast);
+   QModelIndex translated = yeastTableProxy->mapToSource(selected[0]);
+   auto yeast = yeastTableModel->getRow(translated.row());
+   ObjectStoreWrapper::softDelete(*yeast);
+   return;
 }
 
 void YeastDialog::addYeast(const QModelIndex& index)
 {
    QModelIndex translated;
-   
+
    if( !index.isValid() )
    {
       QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
@@ -173,50 +173,53 @@ void YeastDialog::addYeast(const QModelIndex& index)
       else
          return;
    }
-   
-   Yeast* yeast = yeastTableModel->getYeast(translated.row());
-   
+
    // Adds a copy of yeast.
-   Database::instance().addToRecipe( mainWindow->currentRecipe(), yeast );
+   MainWindow::instance().addYeastToRecipe(yeastTableModel->getRow(translated.row()));
+
+   return;
 }
 
-void YeastDialog::editSelected()
-{
+void YeastDialog::editSelected() {
    QModelIndexList selected = tableWidget->selectionModel()->selectedIndexes();
-   QModelIndex translated; 
-
-   int row, size, i;
-
-   size = selected.size();
-   if( size == 0 )
+   int size = selected.size();
+   if (size == 0) {
       return;
+   }
 
    // Make sure only one row is selected.
-   row = selected[0].row();
+   int row = selected[0].row();
 
-   for( i = 1; i < size; ++i )
-   {
-      if( selected[i].row() != row )
+   for (int i = 1; i < size; ++i ) {
+      if (selected[i].row() != row ) {
          return;
+      }
    }
-   translated = yeastTableProxy->mapToSource(selected[0]);
-   Yeast *yeast = yeastTableModel->getYeast(translated.row());
-   yeastEditor->setYeast(yeast);
+   QModelIndex translated = yeastTableProxy->mapToSource(selected[0]);
+   auto yeast = yeastTableModel->getRow(translated.row());
+   yeastEditor->setYeast(yeast.get());
    yeastEditor->show();
+   return;
 }
 
 void YeastDialog::newYeast()
+{
+   newYeast(QString());
+}
+
+void YeastDialog::newYeast(QString folder)
 {
    QString name = QInputDialog::getText(this, tr("Yeast name"),
                                               tr("Yeast name:"));
    if( name.isEmpty() )
       return;
 
-   Yeast* y = Database::instance().newYeast();
-   y->setName(name);
+   Yeast* y = new Yeast(name);
+   if ( ! folder.isEmpty() )
+      y->setFolder(folder);
+
    yeastEditor->setYeast(y);
    yeastEditor->show();
-   y->setDisplay(true);
 }
 
 void YeastDialog::filterYeasts(QString searchExpression)
