@@ -1,7 +1,8 @@
 /*
  * YeastDialog.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2015
+ * authors 2009-2021
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -17,9 +18,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _YEASTDIALOG_H
-#define _YEASTDIALOG_H
+#ifndef YEASTDIALOG_H
+#define YEASTDIALOG_H
 
 #include <QWidget>
 #include <QDialog>
@@ -39,7 +39,7 @@ class YeastSortFilterProxyModel;
 
 /*!
  * \class YeastDialog
- * \author Philip G. Lee
+ *
  *
  * \brief View/controller dialog for displaying all the yeasts in the database.
  */
@@ -64,6 +64,7 @@ public:
    QPushButton *pushButton_remove;
    //! @}
 
+   void newYeast(QString folder);
 public slots:
    void addYeast(const QModelIndex& = QModelIndex());
    void removeYeast();
@@ -91,5 +92,4 @@ private:
    void retranslateUi();
 };
 
-#endif   /* _YEASTDIALOG_H */
-
+#endif   // YEASTDIALOG_H
