@@ -1,6 +1,6 @@
 /*
  * BeerXml.cpp is part of Brewtarget, and is Copyright the following
- * authors 2020-2021
+ * authors 2020-2022
  * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  *
@@ -84,22 +84,15 @@ namespace {
    // Field mappings for <HOP>...</HOP> BeerXML records
    ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    template<> QString const BEER_XML_RECORD_NAME<Hop>{"HOP"};
-   EnumStringMapping const BEER_XML_HOP_USE_MAPPER {
-      {"Boil",       Hop::Use::Boil},
-      {"Dry Hop",    Hop::Use::Dry_Hop},
-      {"Mash",       Hop::Use::Mash},
-      {"First Wort", Hop::Use::First_Wort},
-      {"Aroma",      Hop::Use::UseAroma}
-   };
    EnumStringMapping const BEER_XML_HOP_TYPE_MAPPER {
       {"Bittering",                          Hop::Type::Bittering},
       {"Aroma",                              Hop::Type::Aroma},
-      {"Both",      Hop::Type::Both}
+      {"Both",                               Hop::Type::Both},
    };
    EnumStringMapping const BEER_XML_HOP_FORM_MAPPER {
       {"Pellet", Hop::Form::Pellet},
       {"Plug",   Hop::Form::Plug},
-      {"Leaf",   Hop::Form::Leaf}
+      {"Leaf",   Hop::Form::Leaf},
    };
    template<> XmlRecord::FieldDefinitions const BEER_XML_RECORD_FIELDS<Hop> {
       // Type                                  XPath                    Q_PROPERTY                             Enum Mapper
@@ -107,7 +100,7 @@ namespace {
       {XmlRecord::FieldType::RequiredConstant, "VERSION",               VERSION1,                              nullptr},
       {XmlRecord::FieldType::Double,           "ALPHA",                 PropertyNames::Hop::alpha_pct,         nullptr},
       {XmlRecord::FieldType::Double,           "AMOUNT",                PropertyNames::Hop::amount_kg,         nullptr},
-      {XmlRecord::FieldType::Enum,             "USE",            PropertyNames::Hop::use,               &BEER_XML_HOP_USE_MAPPER},
+      {XmlRecord::FieldType::Enum,             "USE",                   PropertyNames::Hop::use,               &Hop::useStringMapping},
       {XmlRecord::FieldType::Double,           "TIME",                  PropertyNames::Hop::time_min,          nullptr},
       {XmlRecord::FieldType::String,           "NOTES",                 PropertyNames::Hop::notes,             nullptr},
       {XmlRecord::FieldType::Enum,             "TYPE",                  PropertyNames::Hop::type,              &BEER_XML_HOP_TYPE_MAPPER},
@@ -122,7 +115,7 @@ namespace {
       {XmlRecord::FieldType::Double,           "MYRCENE",               PropertyNames::Hop::myrcene_pct,       nullptr},
       {XmlRecord::FieldType::String,           "DISPLAY_AMOUNT",        BtString::NULL_STR,                    nullptr}, // Extension tag
       {XmlRecord::FieldType::String,           "INVENTORY",             BtString::NULL_STR,                    nullptr}, // Extension tag
-      {XmlRecord::FieldType::String,           "DISPLAY_TIME",   BtString::NULL_STR,                    nullptr}  // Extension tag
+      {XmlRecord::FieldType::String,           "DISPLAY_TIME",          BtString::NULL_STR,                    nullptr}, // Extension tag
    };
 
    ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -580,7 +573,7 @@ public:
    /**
     * Export an individual object to BeerXML
     */
-   template<class NE> void toXml(NE & ne, QTextStream & out) {
+   template<class NE> void toXml(NE const & ne, QTextStream & out) {
       std::shared_ptr<XmlRecord> xmlRecord{
          XmlCoding::construct<NE>(BEER_XML_RECORD_NAME<NE>,
                                   this->BeerXml1Coding,
